* {
  padding: 0;
  -GtkToolButton-icon-spacing: 2;
  -GtkTextView-error-underline-color: #cc0000;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkToolItemGroup-expander-size: 11;
  -GtkWidget-text-handle-width: 20;
  -GtkWidget-text-handle-height: 20;
  -GtkDialog-button-spacing: 2;
  -GtkDialog-action-area-border: 0;
  outline-color: alpha(currentColor,0.3);
  outline-style: dashed;
  outline-offset: -3px;
  outline-width: 1px;
  -gtk-outline-radius: 2px;
  -gtk-secondary-caret-color: #215d9c;
}

/***************
 * Base States *
 ***************/
.background {
  color: #eeeeec;
  background-color: #33393b;
}

.background:backdrop {
  color: #f2f2f0;
  background-color: #33393b;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

/*
   These wildcard seems unavoidable, need to investigate.
   Wildcards are bad and troublesome, use them with care,
   or better, just don't.
   Everytime a wildcard is used a kitten dies, painfully.
*/
.gtkstyle-fallback {
  color: #eeeeec;
  background-color: #33393b;
}

.gtkstyle-fallback:hover {
  color: #eeeeec;
  background-color: #4b5356;
}

.gtkstyle-fallback:active {
  color: #eeeeec;
  background-color: #1b1f20;
}

.gtkstyle-fallback:disabled {
  color: #f2f2f0;
  background-color: #2d3234;
}

.gtkstyle-fallback:selected {
  color: #ffffff;
  background-color: #215d9c;
}

.view, iconview,
.view text,
iconview text,
textview text {
  color: white;
  background-color: #232729;
}

.view:backdrop, iconview:backdrop,
.view text:backdrop,
iconview text:backdrop,
textview text:backdrop {
  color: #fefefe;
  background-color: #252a2c;
}

.view:backdrop:disabled, iconview:backdrop:disabled,
.view text:backdrop:disabled,
iconview text:backdrop:disabled,
textview text:backdrop:disabled {
  color: #d1d1cc;
}

.view:disabled, iconview:disabled,
.view text:disabled,
iconview text:disabled,
textview text:disabled {
  color: #f2f2f0;
  background-color: #2d3234;
}

.view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected,
.view text:selected:focus,
iconview text:selected:focus,
textview text:selected:focus,
.view text:selected,
iconview text:selected,
textview text:selected {
  border-radius: 3px;
}

textview border {
  background-color: #2b3032;
}

.rubberband,
rubberband,
flowbox rubberband,
treeview.view rubberband,
.content-view rubberband,
.content-view .rubberband {
  border: 1px solid #184472;
  background-color: rgba(24, 68, 114, 0.2);
}

flowbox flowboxchild {
  padding: 2px;
}

flowbox flowboxchild:selected {
  outline-offset: -2px;
}

.content-view .tile {
  margin: 1px;
  background-color: black;
  border-radius: 0;
  padding: 0;
}

.content-view .tile:backdrop {
  background-color: #1a1d1e;
}

.content-view .tile:active, .content-view .tile:selected {
  background-color: #215d9c;
}

.content-view .tile:disabled {
  background-color: #2d3234;
}

label {
  caret-color: currentColor;
}

label.separator {
  color: #eeeeec;
}

label.separator:backdrop {
  color: #f2f2f0;
}

label selection {
  background-color: #215d9c;
  color: #ffffff;
}

label:disabled {
  color: #f2f2f0;
}

label:disabled:backdrop {
  color: #d1d1cc;
}

label:backdrop {
  color: #f2f2f0;
}

.dim-label, label.separator, .titlebar:not(headerbar) .subtitle,
headerbar .subtitle {
  opacity: 0.55;
  text-shadow: none;
}

assistant .sidebar {
  background-color: #232729;
  border-top: 1px solid #1b1f20;
}

assistant .sidebar:backdrop {
  background-color: #252a2c;
  border-color: #202425;
}

assistant.csd .sidebar {
  border-top-style: none;
}

assistant .sidebar label {
  padding: 4px 8px;
}

assistant .sidebar label.highlight {
  background-color: #585d5e;
}

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier, .csd popover.background.osd, popover.background.osd, .app-notification,
.app-notification.frame, .osd .scale-popup,
.osd {
  color: #eeeeec;
  border: none;
  background-color: rgba(28, 31, 32, 0.7);
  background-clip: padding-box;
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
}

popover.background.touch-selection:backdrop, popover.background.magnifier:backdrop, popover.background.osd:backdrop, .app-notification:backdrop, .osd .scale-popup:backdrop,
.osd:backdrop {
  text-shadow: none;
  -gtk-icon-shadow: none;
}

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

/****************
 * Text Entries *
 ****************/
spinbutton:not(.vertical),
entry {
  min-height: 24px;
  padding-left: 4px;
  padding-right: 4px;
  border: 1px solid;
  border-radius: 2px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: white;
  border-color: #1b1f20;
  background-color: #232729;
  box-shadow: inset 0 0 0 1px rgba(33, 93, 156, 0);
}

spinbutton:not(.vertical) image.left,
entry image.left {
  margin-right: 3px;
}

spinbutton:not(.vertical) image.right,
entry image.right {
  margin-left: 3px;
}

spinbutton:not(.vertical) undershoot.left,
entry undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
  box-shadow: none;
}

spinbutton:not(.vertical) undershoot.right,
entry undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
  box-shadow: none;
}

spinbutton.flat:focus:not(.vertical), spinbutton.flat:not(.vertical),
entry.flat:focus,
entry.flat {
  min-height: 0;
  padding: 2px;
  background-color: transparent;
  border-color: transparent;
  border-radius: 0;
}

spinbutton:focus:not(.vertical),
entry:focus {
  box-shadow: inset 0 0 0 1px #215d9c;
  border-color: #0f2b48;
}

spinbutton:disabled:not(.vertical),
entry:disabled {
  color: #f2f2f0;
  border-color: #1b1f20;
  background-color: #2d3234;
  box-shadow: none;
}

spinbutton:backdrop:not(.vertical),
entry:backdrop {
  color: #fefefe;
  border-color: #202425;
  background-color: #252a2c;
  box-shadow: none;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton:backdrop:disabled:not(.vertical),
entry:backdrop:disabled {
  color: #d1d1cc;
  border-color: #202425;
  background-color: #2d3234;
  box-shadow: none;
}

spinbutton.error:not(.vertical),
entry.error {
  color: #cc0000;
  border-color: #1a0000;
}

spinbutton.error:focus:not(.vertical),
entry.error:focus {
  box-shadow: inset 0 0 0 1px #cc0000;
  border-color: #1a0000;
}

spinbutton.error:not(.vertical) selection,
entry.error selection {
  background-color: #cc0000;
}

spinbutton.warning:not(.vertical),
entry.warning {
  color: #f57900;
  border-color: #432100;
}

spinbutton.warning:focus:not(.vertical),
entry.warning:focus {
  box-shadow: inset 0 0 0 1px #f57900;
  border-color: #432100;
}

spinbutton.warning:not(.vertical) selection,
entry.warning selection {
  background-color: #f57900;
}

spinbutton:not(.vertical) image,
entry image {
  color: #c5c6c5;
}

spinbutton:not(.vertical) image:hover,
entry image:hover {
  color: #eeeeec;
}

spinbutton:not(.vertical) image:active,
entry image:active {
  color: #215d9c;
}

spinbutton:not(.vertical) image:backdrop,
entry image:backdrop {
  color: #c9cac9;
}

spinbutton:drop(active):focus:not(.vertical), spinbutton:drop(active):not(.vertical),
entry:drop(active):focus,
entry:drop(active) {
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 1px #4e9a06;
}

.osd spinbutton:not(.vertical), .osd
entry {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(0, 0, 0, 0.5);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
}

.osd spinbutton:focus:not(.vertical), .osd
entry:focus {
  color: white;
  border-color: #215d9c;
  background-color: rgba(0, 0, 0, 0.5);
  background-clip: padding-box;
  box-shadow: inset 0 0 0 1px #215d9c;
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
}

.osd spinbutton:backdrop:not(.vertical), .osd
entry:backdrop {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(0, 0, 0, 0.5);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.osd spinbutton:disabled:not(.vertical), .osd
entry:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(49, 52, 52, 0.5);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

spinbutton:not(.vertical) progress,
entry progress {
  margin: 2px -6px;
  background-color: transparent;
  background-image: none;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #215d9c;
  border-style: solid;
  box-shadow: none;
}

spinbutton:not(.vertical) progress:backdrop,
entry progress:backdrop {
  background-color: transparent;
}

.linked:not(.vertical) > spinbutton:focus:not(.vertical) + spinbutton:not(.vertical),
.linked:not(.vertical) > spinbutton:focus:not(.vertical) + button,
.linked:not(.vertical) > spinbutton:focus:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) >
entry:focus + spinbutton:not(.vertical),
.linked:not(.vertical) >
entry:focus + button,
.linked:not(.vertical) >
entry:focus + combobox > box > button.combo,
.linked:not(.vertical) > spinbutton:focus:not(.vertical) +
entry, .linked:not(.vertical) >
entry:focus +
entry {
  border-left-color: #0f2b48;
}

.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical),
.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button,
.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) >
entry:drop(active) + spinbutton:not(.vertical),
.linked:not(.vertical) >
entry:drop(active) + button,
.linked:not(.vertical) >
entry:drop(active) + combobox > box > button.combo,
.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) +
entry, .linked:not(.vertical) >
entry:drop(active) +
entry {
  border-left-color: #4e9a06;
}

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled),
.linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical >
entry:not(:disabled) + entry:not(:disabled),
.linked.vertical >
entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) {
  border-top-color: #212426;
}

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled):backdrop,
.linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):backdrop:not(.vertical), .linked.vertical >
entry:not(:disabled) + entry:not(:disabled):backdrop,
.linked.vertical >
entry:not(:disabled) + spinbutton:not(:disabled):backdrop:not(.vertical) {
  border-top-color: #24282a;
}

.linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical),
.linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, .linked.vertical >
entry:disabled + spinbutton:disabled:not(.vertical),
.linked.vertical >
entry:disabled + entry:disabled {
  border-top-color: #212426;
}

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus:not(:only-child):not(.vertical),
.linked.vertical > spinbutton:not(.vertical) + entry:focus:not(:only-child), .linked.vertical >
entry + spinbutton:focus:not(:only-child):not(.vertical),
.linked.vertical >
entry + entry:focus:not(:only-child) {
  border-top-color: #0f2b48;
}

.linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), .linked.vertical >
entry + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical >
entry + entry:drop(active):not(:only-child) {
  border-top-color: #4e9a06;
}

.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + spinbutton:not(.vertical),
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + entry,
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + button,
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical >
entry:focus:not(:only-child) + spinbutton:not(.vertical),
.linked.vertical >
entry:focus:not(:only-child) + entry,
.linked.vertical >
entry:focus:not(:only-child) + button,
.linked.vertical >
entry:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #0f2b48;
}

.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical),
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical >
entry:drop(active):not(:only-child) + spinbutton:not(.vertical),
.linked.vertical >
entry:drop(active):not(:only-child) + entry,
.linked.vertical >
entry:drop(active):not(:only-child) + button,
.linked.vertical >
entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #4e9a06;
}

treeview entry:focus:dir(rtl), treeview entry:focus:dir(ltr) {
  background-color: #232729;
  transition-property: color, background;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #232729;
}

treeview entry.flat:focus, treeview entry:focus {
  border-color: #215d9c;
}

/***********
 * Buttons *
 ***********/
@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #3583d5 0%, rgba(53, 131, 213, 0) 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #3583d5 95%, rgba(53, 131, 213, 0));
  }
}

notebook > header > tabs > arrow,
button {
  min-height: 18px;
  min-width: 18px;
  padding: 2px;
  border: 1px solid;
  border-radius: 3px;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

notebook > header > tabs > arrow.file, notebook > header > tabs > arrow.font, notebook > header > tabs > arrow.lock,
button.file,
button.font,
button.lock {
  padding: 2px;
}

notebook > header > tabs > arrow, button.sidebar-button,
button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  transition: none;
}

notebook > header > tabs > arrow:hover, button.sidebar-button:hover,
button.flat:hover {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 500ms;
}

notebook > header > tabs > arrow:hover:active, button.sidebar-button:hover:active,
button.flat:hover:active {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > arrow:hover,
button:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
}

notebook > header > tabs > arrow:active, notebook > header > tabs > arrow:checked,
button:active,
button:checked {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  background-image: image(#25292b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  transition-duration: 50ms;
}

notebook > header > tabs > arrow:backdrop, button.sidebar-button:backdrop, notebook > header > tabs > arrow:backdrop,
button:backdrop.flat,
button:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > arrow:backdrop label, button.sidebar-button:backdrop label, notebook > header > tabs > arrow:backdrop, button.sidebar-button:backdrop, notebook > header > tabs > arrow:backdrop label, notebook > header > tabs > arrow:backdrop,
button:backdrop.flat label,
button:backdrop.flat,
button:backdrop label,
button:backdrop {
  color: #f2f2f0;
}

notebook > header > tabs > arrow:backdrop:active, button.sidebar-button:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, button.sidebar-button:backdrop:checked, notebook > header > tabs > arrow:backdrop:active, notebook > header > tabs > arrow:backdrop:checked,
button:backdrop.flat:active,
button:backdrop.flat:checked,
button:backdrop:active,
button:backdrop:checked {
  border-color: #202425;
  background-image: image(#272c2d);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

notebook > header > tabs > arrow:backdrop:active label, button.sidebar-button:backdrop:active label, notebook > header > tabs > arrow:backdrop:active, button.sidebar-button:backdrop:active, notebook > header > tabs > arrow:backdrop:checked label, button.sidebar-button:backdrop:checked label, notebook > header > tabs > arrow:backdrop:checked, button.sidebar-button:backdrop:checked, notebook > header > tabs > arrow:backdrop:active label, notebook > header > tabs > arrow:backdrop:active, notebook > header > tabs > arrow:backdrop:checked label, notebook > header > tabs > arrow:backdrop:checked,
button:backdrop.flat:active label,
button:backdrop.flat:active,
button:backdrop.flat:checked label,
button:backdrop.flat:checked,
button:backdrop:active label,
button:backdrop:active,
button:backdrop:checked label,
button:backdrop:checked {
  color: #f2f2f0;
}

notebook > header > tabs > arrow:backdrop:disabled, button.sidebar-button:backdrop:disabled, notebook > header > tabs > arrow:backdrop:disabled,
button:backdrop.flat:disabled,
button:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

notebook > header > tabs > arrow:backdrop:disabled label, button.sidebar-button:backdrop:disabled label, notebook > header > tabs > arrow:backdrop:disabled, button.sidebar-button:backdrop:disabled, notebook > header > tabs > arrow:backdrop:disabled label, notebook > header > tabs > arrow:backdrop:disabled,
button:backdrop.flat:disabled label,
button:backdrop.flat:disabled,
button:backdrop:disabled label,
button:backdrop:disabled {
  color: #d1d1cc;
}

notebook > header > tabs > arrow:backdrop:disabled:active, button.sidebar-button:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked, button.sidebar-button:backdrop:disabled:checked, notebook > header > tabs > arrow:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked,
button:backdrop.flat:disabled:active,
button:backdrop.flat:disabled:checked,
button:backdrop:disabled:active,
button:backdrop:disabled:checked {
  border-color: #202425;
  background-image: image(#272c2d);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

notebook > header > tabs > arrow:backdrop:disabled:active label, button.sidebar-button:backdrop:disabled:active label, notebook > header > tabs > arrow:backdrop:disabled:checked label, button.sidebar-button:backdrop:disabled:checked label, notebook > header > tabs > arrow:backdrop:disabled:active label, notebook > header > tabs > arrow:backdrop:disabled:checked label,
button:backdrop.flat:disabled:active label,
button:backdrop.flat:disabled:checked label,
button:backdrop:disabled:active label,
button:backdrop:disabled:checked label {
  color: #d1d1cc;
}

notebook > header > tabs > arrow:backdrop, button.sidebar-button:backdrop, notebook > header > tabs > arrow:disabled, button.sidebar-button:disabled, notebook > header > tabs > arrow:backdrop:disabled, button.sidebar-button:backdrop:disabled,
button.flat:backdrop,
button.flat:disabled,
button.flat:backdrop:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

notebook > header > tabs > arrow:disabled,
button:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

notebook > header > tabs > arrow:disabled label, notebook > header > tabs > arrow:disabled,
button:disabled label,
button:disabled {
  color: #f2f2f0;
}

notebook > header > tabs > arrow:disabled:active, notebook > header > tabs > arrow:disabled:checked,
button:disabled:active,
button:disabled:checked {
  border-color: #1b1f20;
  background-image: image(#232628);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

notebook > header > tabs > arrow:disabled:active label, notebook > header > tabs > arrow:disabled:active, notebook > header > tabs > arrow:disabled:checked label, notebook > header > tabs > arrow:disabled:checked,
button:disabled:active label,
button:disabled:active,
button:disabled:checked label,
button:disabled:checked {
  color: #f2f2f0;
}

notebook > header > tabs > arrow.image-button,
button.image-button {
  min-width: 18px;
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header > tabs > arrow.text-button,
button.text-button {
  padding-left: 8px;
  padding-right: 8px;
}

notebook > header > tabs > arrow.text-button.image-button,
button.text-button.image-button {
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header > tabs > arrow.text-button.image-button label,
button.text-button.image-button label {
  padding-left: 4px;
  padding-right: 4px;
}

combobox:drop(active) button.combo, notebook > header > tabs > arrow:drop(active),
button:drop(active) {
  color: #4e9a06;
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 1px #4e9a06;
}

row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), row:selected
button.flat:not(:active):not(:checked):not(:hover):not(disabled) {
  color: #ffffff;
  border-color: transparent;
}

row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected
button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop {
  color: #f2f2f0;
}


button.osd {
  min-width: 24px;
  min-height: 24px;
  color: #eeeeec;
  border-radius: 3px;
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
  border: none;
  box-shadow: none;
}


button.osd.image-button {
  min-width: 24px;
}


button.osd:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(57, 63, 65, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
  border: none;
  box-shadow: none;
}


button.osd:active,
button.osd:checked {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
  border: none;
  box-shadow: none;
}


button.osd:disabled:backdrop,
button.osd:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  border: none;
}


button.osd:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  border: none;
}

.csd popover.background.touch-selection button, .csd popover.background.magnifier button, popover.background.touch-selection button, popover.background.magnifier button, .app-notification button,
.app-notification.frame button,
.osd
button {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .app-notification button:hover,
.osd
button:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(57, 63, 65, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

popover.background.touch-selection button:active:backdrop, popover.background.magnifier button:active:backdrop, .app-notification button:active:backdrop, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:active, popover.background.touch-selection button:checked:backdrop, popover.background.magnifier button:checked:backdrop, .app-notification button:checked:backdrop, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .app-notification button:checked,
.osd
button:active:backdrop,
.osd
button:active,
.osd
button:checked:backdrop,
.osd
button:checked {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}

popover.background.touch-selection button:disabled:backdrop, popover.background.magnifier button:disabled:backdrop, .app-notification button:disabled:backdrop, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .app-notification button:disabled,
.osd
button:disabled:backdrop,
.osd
button:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop, .app-notification button:backdrop,
.osd
button:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

popover.background.touch-selection button.flat, popover.background.magnifier button.flat, .app-notification button.flat,
.osd
button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: none;
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
}

popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover, .app-notification button.flat:hover,
.osd
button.flat:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(57, 63, 65, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled, .app-notification button.flat:disabled,
.osd
button.flat:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  background-image: none;
  border-color: transparent;
  box-shadow: none;
}

popover.background.touch-selection button.flat:backdrop, popover.background.magnifier button.flat:backdrop, .app-notification button.flat:backdrop,
.osd
button.flat:backdrop {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, .app-notification button.flat:active, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked, .app-notification button.flat:checked,
.osd
button.flat:active,
.osd
button.flat:checked {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}


button.suggested-action {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  background-image: linear-gradient(to bottom, #1f5894, #1d538b 60%, #1b4e83);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.selection-mode button.titlebutton,
button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #215d9c;
}


button.suggested-action:hover {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #2260a0, #1f5894 60%, #1d538b);
}


button.suggested-action:active,
button.suggested-action:checked {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  background-image: image(#1b4e83);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.selection-mode button.titlebutton:backdrop,
button.suggested-action:backdrop,
button.suggested-action.flat:backdrop {
  border-color: #0f2b48;
  background-image: image(#215d9c);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.selection-mode button.titlebutton:backdrop label, .selection-mode button.titlebutton:backdrop,
button.suggested-action:backdrop label,
button.suggested-action:backdrop,
button.suggested-action.flat:backdrop label,
button.suggested-action.flat:backdrop {
  color: #d3dfeb;
}

.selection-mode button.titlebutton:backdrop:active, .selection-mode button.titlebutton:backdrop:checked,
button.suggested-action:backdrop:active,
button.suggested-action:backdrop:checked,
button.suggested-action.flat:backdrop:active,
button.suggested-action.flat:backdrop:checked {
  border-color: #0f2b48;
  background-image: image(#1d4b7b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.selection-mode button.titlebutton:backdrop:active label, .selection-mode button.titlebutton:backdrop:active, .selection-mode button.titlebutton:backdrop:checked label, .selection-mode button.titlebutton:backdrop:checked,
button.suggested-action:backdrop:active label,
button.suggested-action:backdrop:active,
button.suggested-action:backdrop:checked label,
button.suggested-action:backdrop:checked,
button.suggested-action.flat:backdrop:active label,
button.suggested-action.flat:backdrop:active,
button.suggested-action.flat:backdrop:checked label,
button.suggested-action.flat:backdrop:checked {
  color: #d2dbe5;
}

.selection-mode button.titlebutton:backdrop:disabled,
button.suggested-action:backdrop:disabled,
button.suggested-action.flat:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.selection-mode button.titlebutton:backdrop:disabled label, .selection-mode button.titlebutton:backdrop:disabled,
button.suggested-action:backdrop:disabled label,
button.suggested-action:backdrop:disabled,
button.suggested-action.flat:backdrop:disabled label,
button.suggested-action.flat:backdrop:disabled {
  color: #d1d1cc;
}

.selection-mode button.titlebutton:backdrop:disabled:active, .selection-mode button.titlebutton:backdrop:disabled:checked,
button.suggested-action:backdrop:disabled:active,
button.suggested-action:backdrop:disabled:checked,
button.suggested-action.flat:backdrop:disabled:active,
button.suggested-action.flat:backdrop:disabled:checked {
  border-color: #0f2b48;
  background-image: image(#1d4b7b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.selection-mode button.titlebutton:backdrop:disabled:active label, .selection-mode button.titlebutton:backdrop:disabled:checked label,
button.suggested-action:backdrop:disabled:active label,
button.suggested-action:backdrop:disabled:checked label,
button.suggested-action.flat:backdrop:disabled:active label,
button.suggested-action.flat:backdrop:disabled:checked label {
  color: #6c8aa9;
}

.selection-mode button.titlebutton:backdrop, .selection-mode button.titlebutton:disabled, .selection-mode button.titlebutton:backdrop:disabled,
button.suggested-action.flat:backdrop,
button.suggested-action.flat:disabled,
button.suggested-action.flat:backdrop:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: rgba(33, 93, 156, 0.8);
}


button.suggested-action:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.suggested-action:disabled label,
button.suggested-action:disabled {
  color: #f2f2f0;
}


button.suggested-action:disabled:active,
button.suggested-action:disabled:checked {
  border-color: #0f2b48;
  background-image: image(#1b4672);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.suggested-action:disabled:active label,
button.suggested-action:disabled:active,
button.suggested-action:disabled:checked label,
button.suggested-action:disabled:checked {
  color: #a4b5c7;
}

.osd
button.suggested-action {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(33, 93, 156, 0.5));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.suggested-action:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(33, 93, 156, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.suggested-action:active:backdrop, .osd
button.suggested-action:active, .osd
button.suggested-action:checked:backdrop, .osd
button.suggested-action:checked {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(#215d9c);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.suggested-action:disabled:backdrop, .osd
button.suggested-action:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.osd
button.suggested-action:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(33, 93, 156, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}


button.destructive-action {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #760909;
  border-bottom-color: #470505;
  background-image: linear-gradient(to bottom, #cc0f0f, #c20f0f 60%, #b90e0e);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.640784);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.640784);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.2);
}


button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #d51010;
}


button.destructive-action:hover {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #760909;
  border-bottom-color: #470505;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.592784);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.592784);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.2);
  background-image: linear-gradient(to bottom, #da1010, #cc0f0f 60%, #c20f0f);
}


button.destructive-action:active,
button.destructive-action:checked {
  color: white;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #760909;
  background-image: image(#b90e0e);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}


button.destructive-action:backdrop,
button.destructive-action.flat:backdrop {
  border-color: #760909;
  background-image: image(#d51010);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:backdrop label,
button.destructive-action:backdrop,
button.destructive-action.flat:backdrop label,
button.destructive-action.flat:backdrop {
  color: #f7cfcf;
}


button.destructive-action:backdrop:active,
button.destructive-action:backdrop:checked,
button.destructive-action.flat:backdrop:active,
button.destructive-action.flat:backdrop:checked {
  border-color: #760909;
  background-image: image(#a71112);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:backdrop:active label,
button.destructive-action:backdrop:active,
button.destructive-action:backdrop:checked label,
button.destructive-action:backdrop:checked,
button.destructive-action.flat:backdrop:active label,
button.destructive-action.flat:backdrop:active,
button.destructive-action.flat:backdrop:checked label,
button.destructive-action.flat:backdrop:checked {
  color: #edcfd0;
}


button.destructive-action:backdrop:disabled,
button.destructive-action.flat:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:backdrop:disabled label,
button.destructive-action:backdrop:disabled,
button.destructive-action.flat:backdrop:disabled label,
button.destructive-action.flat:backdrop:disabled {
  color: #d1d1cc;
}


button.destructive-action:backdrop:disabled:active,
button.destructive-action:backdrop:disabled:checked,
button.destructive-action.flat:backdrop:disabled:active,
button.destructive-action.flat:backdrop:disabled:checked {
  border-color: #760909;
  background-image: image(#a71112);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:backdrop:disabled:active label,
button.destructive-action:backdrop:disabled:checked label,
button.destructive-action.flat:backdrop:disabled:active label,
button.destructive-action.flat:backdrop:disabled:checked label {
  color: #c66465;
}


button.destructive-action.flat:backdrop,
button.destructive-action.flat:disabled,
button.destructive-action.flat:backdrop:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: rgba(213, 16, 16, 0.8);
}


button.destructive-action:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:disabled label,
button.destructive-action:disabled {
  color: #f2f2f0;
}


button.destructive-action:disabled:active,
button.destructive-action:disabled:checked {
  border-color: #760909;
  background-image: image(#9e1011);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}


button.destructive-action:disabled:active label,
button.destructive-action:disabled:active,
button.destructive-action:disabled:checked label,
button.destructive-action:disabled:checked {
  color: #d89fa0;
}

.osd
button.destructive-action {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(213, 16, 16, 0.5));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.destructive-action:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(213, 16, 16, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.destructive-action:active:backdrop, .osd
button.destructive-action:active, .osd
button.destructive-action:checked:backdrop, .osd
button.destructive-action:checked {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(#d51010);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd
button.destructive-action:disabled:backdrop, .osd
button.destructive-action:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.osd
button.destructive-action:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(213, 16, 16, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.stack-switcher >
button {
  outline-offset: -3px;
}

.stack-switcher >
button > label {
  padding-left: 6px;
  padding-right: 6px;
}

.stack-switcher >
button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 2px;
  padding-bottom: 2px;
}

.stack-switcher >
button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

.stack-switcher >
button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

.stack-switcher >
button.needs-attention:active > label,
.stack-switcher >
button.needs-attention:active > image, .stack-switcher >
button.needs-attention:checked > label,
.stack-switcher >
button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}


button.font separator,
button.file separator {
  background-color: transparent;
}


button.font > box > box > label {
  font-weight: bold;
}

.inline-toolbar
button, .inline-toolbar
button:backdrop {
  border-radius: 2px;
  border-width: 1px;
}

.primary-toolbar
button {
  -gtk-icon-shadow: none;
}


button.circular {
  border-radius: 9999px;
  -gtk-outline-radius: 9999px;
  padding: 2px;
  background-origin: padding-box, border-box;
  background-clip: padding-box, border-box;
}


button.circular label {
  padding: 0;
}


button.circular:not(.flat):not(:checked):not(:active):not(:disabled):not(:backdrop) {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b), linear-gradient(to top, #0b0c0c 25%, #1b1f20 50%);
  border-color: transparent;
}


button.circular:hover:not(:checked):not(:active):not(:disabled):not(:backdrop) {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30), linear-gradient(to top, #0b0c0c 25%, #1b1f20 50%);
  border-color: transparent;
}

.stack-switcher >
button.needs-attention > label,
.stack-switcher >
button.needs-attention > image, stacksidebar.needs-attention > label {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #3583d5 96%, rgba(53, 131, 213, 0)), radial-gradient(farthest-side, rgba(0, 0, 0, 0.827451) 95%, transparent);
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 2px;
}

.stack-switcher >
button.needs-attention > label:backdrop,
.stack-switcher >
button.needs-attention > image:backdrop, stacksidebar.needs-attention > label:backdrop {
  background-size: 6px 6px, 0 0;
}

.stack-switcher >
button.needs-attention > label:dir(rtl),
.stack-switcher >
button.needs-attention > image:dir(rtl), stacksidebar.needs-attention > label:dir(rtl) {
  background-position: left 3px, left 2px;
}

.inline-toolbar toolbutton > button {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.inline-toolbar toolbutton > button:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
}

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  background-image: image(#25292b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.inline-toolbar toolbutton > button:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled {
  color: #f2f2f0;
}

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked {
  border-color: #1b1f20;
  background-image: image(#232628);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked {
  color: #f2f2f0;
}

.inline-toolbar toolbutton > button:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:backdrop label, .inline-toolbar toolbutton > button:backdrop {
  color: #f2f2f0;
}

.inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked {
  border-color: #202425;
  background-image: image(#272c2d);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:backdrop:active label, .inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked label, .inline-toolbar toolbutton > button:backdrop:checked {
  color: #f2f2f0;
}

.inline-toolbar toolbutton > button:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:backdrop:disabled label, .inline-toolbar toolbutton > button:backdrop:disabled {
  color: #d1d1cc;
}

.inline-toolbar toolbutton > button:backdrop:disabled:active, .inline-toolbar toolbutton > button:backdrop:disabled:checked {
  border-color: #202425;
  background-image: image(#272c2d);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.inline-toolbar toolbutton > button:backdrop:disabled:active label, .inline-toolbar toolbutton > button:backdrop:disabled:checked label {
  color: #d1d1cc;
}

toolbar.inline-toolbar toolbutton > button.flat,
toolbar.inline-toolbar toolbutton:backdrop > button.flat, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .inline-toolbar button, .inline-toolbar button:backdrop, .linked > button,
.linked > button:hover,
.linked > button:active,
.linked > button:checked,
.linked > button:backdrop, .linked > combobox > box > button.combo:dir(ltr), .linked > combobox > box > button.combo:dir(rtl) {
  border-radius: 0;
  border-right-style: none;
}

.linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .linked > button:first-child, toolbar.inline-toolbar toolbutton:first-child > button.flat,
toolbar.inline-toolbar toolbutton:backdrop:first-child > button.flat, combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .linked > button:last-child, toolbar.inline-toolbar toolbutton:last-child > button.flat,
toolbar.inline-toolbar toolbutton:backdrop:last-child > button.flat, combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .linked > button:only-child, toolbar.inline-toolbar toolbutton:only-child > button.flat,
toolbar.inline-toolbar toolbutton:backdrop:only-child > button.flat, .linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

.linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .linked.vertical > button,
.linked.vertical > button:hover,
.linked.vertical > button:active,
.linked.vertical > button:checked,
.linked.vertical > button:backdrop, .linked.vertical > combobox > box > button.combo {
  border-style: solid solid none solid;
  border-radius: 0;
}

.linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .linked.vertical > button:first-child, .linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

.linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .linked.vertical > button:last-child, .linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-style: solid;
}

.linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .linked.vertical > button:only-child, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

modelbutton.flat,
.menuitem.button.flat, modelbutton.flat:backdrop, modelbutton.flat:backdrop:hover,
.menuitem.button.flat:backdrop,
.menuitem.button.flat:backdrop:hover, button:link,
button:visited, button:link:hover, button:link:active, button:link:checked,
button:visited:hover,
button:visited:active,
button:visited:checked, calendar.button, .scale-popup button:hover, .scale-popup button:backdrop:hover, .scale-popup button:backdrop:disabled, .scale-popup button:backdrop, button.titlebutton, button.titlebutton:hover, button.titlebutton:active {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

/* menu buttons */
modelbutton.flat,
.menuitem.button.flat {
  min-height: 26px;
  padding-left: 5px;
  padding-right: 5px;
  border-radius: 0px;
  outline-offset: -2px;
}

modelbutton.flat:hover,
.menuitem.button.flat:hover {
  background-color: #3f4649;
}

modelbutton.flat arrow {
  background: none;
}

modelbutton.flat arrow:hover {
  background: none;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

button.color {
  padding: 2px;
}

button.color colorswatch:only-child, button.color colorswatch:only-child overlay {
  border-radius: 0;
}

/*********
 * Links *
 *********/
button:link > label,
button:visited > label,
*:link,
button:link,
button:visited {
  color: #4a90d9;
}

button:link > label:visited,
button:visited > label:visited,
*:link:visited,
button:visited {
  color: #2a76c6;
}

*:selected button:link > label:visited, *:selected
button:visited > label:visited,
*:selected
*:link:visited,
*:selected button:visited:link,
*:selected
button:visited {
  color: #a6bed7;
}

button:link > label:hover,
button:visited > label:hover,
*:link:hover,
button:hover:link,
button:hover:visited {
  color: #74aae2;
}

*:selected button:link > label:hover, *:selected
button:visited > label:hover,
*:selected
*:link:hover,
*:selected button:hover:link,
*:selected
button:hover:visited {
  color: #e9eff5;
}

button:link > label:active,
button:visited > label:active,
*:link:active,
button:active:link,
button:active:visited {
  color: #4a90d9;
}

*:selected button:link > label:active, *:selected
button:visited > label:active,
*:selected
*:link:active,
*:selected button:active:link,
*:selected
button:active:visited {
  color: #d3dfeb;
}

button:link > label:backdrop:backdrop:hover,
button:visited > label:backdrop:backdrop:hover, button:link > label:backdrop:backdrop:hover:selected,
button:visited > label:backdrop:backdrop:hover:selected, button:link > label:backdrop,
button:visited > label:backdrop,
*:link:backdrop:backdrop:hover,
button:backdrop:backdrop:hover:link,
button:backdrop:backdrop:hover:visited,
*:link:backdrop:backdrop:hover:selected,
button:backdrop:backdrop:hover:selected:link,
button:backdrop:backdrop:hover:selected:visited,
.titlebar:not(headerbar) button.selection-mode .subtitle:backdrop:backdrop:hover:link,
headerbar button.selection-mode .subtitle:backdrop:backdrop:hover:link,
*:link:backdrop,
button:backdrop:link,
button:backdrop:visited {
  color: #215d9c;
}

infobar.info *:link, infobar.info button:link, infobar.info
button:visited, infobar.question *:link, infobar.question button:link, infobar.question
button:visited, infobar.warning *:link, infobar.warning button:link, infobar.warning
button:visited, infobar.error *:link, infobar.error button:link, infobar.error
button:visited, button:link > label:selected,
button:visited > label:selected,
*:selected button:link > label,
*:selected
button:visited > label,
*:link:selected,
button:selected:link,
button:selected:visited,
.titlebar:not(headerbar) button.selection-mode .subtitle:link,
headerbar button.selection-mode .subtitle:link,
*:selected
*:link,
*:selected button:link,
*:selected
button:visited {
  color: #d3dfeb;
}

button:link,
button:visited {
  text-shadow: none;
}

button:link:hover, button:link:active, button:link:checked,
button:visited:hover,
button:visited:active,
button:visited:checked {
  text-shadow: none;
}

button:link > label,
button:visited > label {
  text-decoration-line: underline;
}

/*****************
 * GtkSpinButton *
 *****************/
spinbutton:not(.vertical) {
  padding: 0;
}

spinbutton:not(.vertical) entry {
  min-width: 24px;
  margin: 0;
  background: none;
  background-color: transparent;
  border: none;
  border-radius: 0;
  box-shadow: none;
}

spinbutton:not(.vertical) entry:backdrop:disabled {
  background-color: transparent;
}

spinbutton:not(.vertical) button {
  min-height: 16px;
  margin: 0;
  padding-bottom: 0;
  padding-top: 0;
  color: #dadad9;
  background-image: none;
  border-style: none none none solid;
  border-color: rgba(27, 31, 32, 0.3);
  border-radius: 0;
  box-shadow: none;
}

spinbutton:not(.vertical) button:dir(rtl) {
  border-style: none solid none none;
}

spinbutton:not(.vertical) button:hover {
  color: #eeeeec;
  background-color: rgba(238, 238, 236, 0.05);
}

spinbutton:not(.vertical) button:disabled {
  color: rgba(242, 242, 240, 0.3);
  background-color: transparent;
}

spinbutton:not(.vertical) button:active {
  background-color: rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2);
}

spinbutton:not(.vertical) button:backdrop {
  color: #dededc;
  background-color: transparent;
  border-color: rgba(32, 36, 37, 0.3);
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton:not(.vertical) button:backdrop:disabled {
  color: rgba(209, 209, 204, 0.3);
  background-color: transparent;
  border-style: none none none solid;
}

spinbutton:not(.vertical) button:backdrop:disabled:dir(rtl) {
  border-style: none solid none none;
}

spinbutton:not(.vertical) button:dir(ltr):last-child {
  border-radius: 0 3px 3px 0;
}

spinbutton:not(.vertical) button:dir(rtl):first-child {
  border-radius: 3px 0 0 3px;
}

.osd spinbutton:not(.vertical) button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eeeeec;
  border-style: none none none solid;
  border-color: rgba(0, 0, 0, 0.4);
  border-radius: 0;
  box-shadow: none;
  -gtk-icon-shadow: 0 1px black;
}

.osd spinbutton:not(.vertical) button:dir(rtl) {
  border-style: none solid none none;
}

.osd spinbutton:not(.vertical) button:hover {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.5);
  background-color: rgba(238, 238, 236, 0.1);
  -gtk-icon-shadow: 0 1px black;
  box-shadow: none;
}

.osd spinbutton:not(.vertical) button:backdrop {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.5);
  -gtk-icon-shadow: none;
  box-shadow: none;
}

.osd spinbutton:not(.vertical) button:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #858786;
  border-color: rgba(0, 0, 0, 0.5);
  -gtk-icon-shadow: none;
  box-shadow: none;
}

.osd spinbutton:not(.vertical) button:dir(ltr):last-child {
  border-radius: 0 3px 3px 0;
}

.osd spinbutton:not(.vertical) button:dir(rtl):first-child {
  border-radius: 3px 0 0 3px;
}

spinbutton.vertical:disabled {
  color: #f2f2f0;
}

spinbutton.vertical:backdrop:disabled {
  color: #d1d1cc;
}

spinbutton.vertical:drop(active) {
  border-color: transparent;
  box-shadow: none;
}

spinbutton.vertical entry {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 0;
}

spinbutton.vertical button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
}

spinbutton.vertical button.up {
  border-radius: 3px 3px 0 0;
  border-style: solid solid none solid;
}

spinbutton.vertical button.down {
  border-radius: 0 0 3px 3px;
  border-style: none solid solid solid;
}

.osd spinbutton.vertical button:first-child {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd spinbutton.vertical button:first-child:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(57, 63, 65, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd spinbutton.vertical button:first-child:active {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd spinbutton.vertical button:first-child:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.osd spinbutton.vertical button:first-child:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) entry {
  min-height: 0;
  padding: 1px 2px;
}

/**************
 * ComboBoxes *
 **************/
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

combobox:drop(active) {
  box-shadow: none;
}

/************
 * Toolbars *
 ************/
toolbar, .toolbar, .inline-toolbar, searchbar,
.location-bar {
  -GtkWidget-window-dragging: true;
  padding: 2px;
}

toolbar, .toolbar {
  padding: 3px;
}

toolbar.horizontal:not(.inline-toolbar) toolitem label, .toolbar.horizontal:not(.inline-toolbar) toolitem label {
  color: #eeeeec;
}

toolbar toolbutton > button:disabled, toolbar toolbutton > button:backdrop:disabled, .toolbar toolbutton > button:disabled, .toolbar toolbutton > button:backdrop:disabled {
  -gtk-icon-effect: dim;
}

toolbar toolitem label, .toolbar toolitem label {
  color: #eeeeec;
}

.osd toolbar, .osd .toolbar {
  background-color: transparent;
}

toolbar.osd, .toolbar.osd {
  padding: 13px;
  border: none;
  border-radius: 4px;
  background-color: rgba(28, 31, 32, 0.7);
}

toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom, .toolbar.osd.left, .toolbar.osd.right, .toolbar.osd.top, .toolbar.osd.bottom {
  border-radius: 0;
}

toolbar.horizontal separator, .toolbar.horizontal separator {
  margin: 0 7px 1px 6px;
}

toolbar.vertical separator, .toolbar.vertical separator {
  margin: 6px 1px 7px 0;
}

toolbar:not(.inline-toolbar):not(.osd) switch,
toolbar:not(.inline-toolbar):not(.osd) scale,
toolbar:not(.inline-toolbar):not(.osd) entry,
toolbar:not(.inline-toolbar):not(.osd) spinbutton,
toolbar:not(.inline-toolbar):not(.osd) button, .toolbar:not(.inline-toolbar):not(.osd) switch,
.toolbar:not(.inline-toolbar):not(.osd) scale,
.toolbar:not(.inline-toolbar):not(.osd) entry,
.toolbar:not(.inline-toolbar):not(.osd) spinbutton,
.toolbar:not(.inline-toolbar):not(.osd) button {
  margin-right: 1px;
  margin-bottom: 1px;
}

.inline-toolbar {
  padding: 3px;
  border-width: 0 1px 1px;
  border-radius: 0  0 5px 5px;
}

searchbar,
.location-bar {
  border-width: 0 0 1px;
  padding: 3px;
}

.inline-toolbar, searchbar,
.location-bar {
  border-style: solid;
  border-color: #1b1f20;
  background-color: #2c3133;
}

.inline-toolbar:backdrop, searchbar:backdrop,
.location-bar:backdrop {
  border-color: #202425;
  background-color: #2c3233;
  box-shadow: none;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

/***************
 * Header bars *
 ***************/
.titlebar:not(headerbar),
headerbar {
  padding: 0 5px;
  min-height: 32px;
  border-width: 0 0 1px;
  border-style: solid;
  border-radius: 0;
  color: #eeeeec;
  background: #33393b linear-gradient(to top, #212526, #33393b);
  box-shadow: inset 0 1px rgba(46, 52, 54, 0.07);
}

.titlebar:not(headerbar) ~ separator,
headerbar ~ separator {
  background-image: image(#0b0c0c);
}

.titlebar:not(headerbar), .titlebar:first-child:not(headerbar), .titlebar:last-child:not(headerbar), .titlebar:first-child:last-child:not(headerbar),
headerbar,
headerbar:first-child,
headerbar:last-child,
headerbar:first-child:last-child {
  border-color: #0b0c0c;
}

.titlebar:backdrop:not(headerbar), .titlebar:first-child:backdrop:not(headerbar), .titlebar:last-child:backdrop:not(headerbar), .titlebar:first-child:last-child:backdrop:not(headerbar),
headerbar:backdrop,
headerbar:first-child:backdrop,
headerbar:last-child:backdrop,
headerbar:first-child:last-child:backdrop {
  border-color: #202425;
}

.titlebar:backdrop:not(headerbar),
headerbar:backdrop {
  background-image: none;
}

.titlebar:backdrop:not(headerbar),
headerbar:backdrop {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.titlebar:not(headerbar) label:backdrop,
headerbar label:backdrop {
  color: #f2f2f0;
}

.titlebar:not(headerbar) .title,
headerbar .title {
  padding-left: 8px;
  padding-right: 8px;
  font-weight: bold;
}

.titlebar:not(headerbar) .subtitle,
headerbar .subtitle {
  font-size: smaller;
  padding-left: 12px;
  padding-right: 12px;
}

.titlebar:not(headerbar) button.selection-mode,
headerbar button.selection-mode {
  color: #ffffff;
  border-color: #0f2b48;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.5);
  background: #215d9c linear-gradient(to top, #1a4a7d, #215d9c);
  box-shadow: inset 0 1px rgba(33, 92, 153, 0.535);
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  background-image: linear-gradient(to bottom, #1f5894, #1d538b 60%, #1b4e83);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.titlebar:not(headerbar) button.selection-mode:backdrop,
headerbar button.selection-mode:backdrop {
  background-image: none;
}

.titlebar:not(headerbar) button.selection-mode:backdrop,
headerbar button.selection-mode:backdrop {
  background-color: #215d9c;
  background-image: none;
  box-shadow: inset 0 1px rgba(33, 91, 151, 0.442);
}

.titlebar:not(headerbar) button.selection-mode.flat,
headerbar button.selection-mode.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.titlebar:not(headerbar) button.selection-mode:hover,
headerbar button.selection-mode:hover {
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #2260a0, #1f5894 60%, #1d538b);
}

.titlebar:not(headerbar) button.selection-mode:active, .titlebar:not(headerbar) button.selection-mode:checked,
headerbar button.selection-mode:active,
headerbar button.selection-mode:checked {
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  background-image: image(#1b4e83);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat, .titlebar:not(headerbar) button.selection-mode:backdrop,
headerbar button.selection-mode:backdrop.flat,
headerbar button.selection-mode:backdrop {
  border-color: #0f2b48;
  background-image: image(#215d9c);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat label, .titlebar:not(headerbar) button.selection-mode:backdrop.flat, .titlebar:not(headerbar) button.selection-mode:backdrop label, .titlebar:not(headerbar) button.selection-mode:backdrop,
headerbar button.selection-mode:backdrop.flat label,
headerbar button.selection-mode:backdrop.flat,
headerbar button.selection-mode:backdrop label,
headerbar button.selection-mode:backdrop {
  color: #d3dfeb;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:active, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:checked, .titlebar:not(headerbar) button.selection-mode:backdrop:active, .titlebar:not(headerbar) button.selection-mode:backdrop:checked,
headerbar button.selection-mode:backdrop.flat:active,
headerbar button.selection-mode:backdrop.flat:checked,
headerbar button.selection-mode:backdrop:active,
headerbar button.selection-mode:backdrop:checked {
  border-color: #0f2b48;
  background-image: image(#1d4b7b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:active label, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:active, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:checked label, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:checked, .titlebar:not(headerbar) button.selection-mode:backdrop:active label, .titlebar:not(headerbar) button.selection-mode:backdrop:active, .titlebar:not(headerbar) button.selection-mode:backdrop:checked label, .titlebar:not(headerbar) button.selection-mode:backdrop:checked,
headerbar button.selection-mode:backdrop.flat:active label,
headerbar button.selection-mode:backdrop.flat:active,
headerbar button.selection-mode:backdrop.flat:checked label,
headerbar button.selection-mode:backdrop.flat:checked,
headerbar button.selection-mode:backdrop:active label,
headerbar button.selection-mode:backdrop:active,
headerbar button.selection-mode:backdrop:checked label,
headerbar button.selection-mode:backdrop:checked {
  color: #d2dbe5;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled,
headerbar button.selection-mode:backdrop.flat:disabled,
headerbar button.selection-mode:backdrop:disabled {
  border-color: #0f2b48;
  background-image: image(#21558b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled label, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled label, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled,
headerbar button.selection-mode:backdrop.flat:disabled label,
headerbar button.selection-mode:backdrop.flat:disabled,
headerbar button.selection-mode:backdrop:disabled label,
headerbar button.selection-mode:backdrop:disabled {
  color: #6f91b4;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled:active, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled:checked, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled:active, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled:checked,
headerbar button.selection-mode:backdrop.flat:disabled:active,
headerbar button.selection-mode:backdrop.flat:disabled:checked,
headerbar button.selection-mode:backdrop:disabled:active,
headerbar button.selection-mode:backdrop:disabled:checked {
  border-color: #0f2b48;
  background-image: image(#1d4b7b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled:active label, .titlebar:not(headerbar) button.selection-mode:backdrop.flat:disabled:checked label, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled:active label, .titlebar:not(headerbar) button.selection-mode:backdrop:disabled:checked label,
headerbar button.selection-mode:backdrop.flat:disabled:active label,
headerbar button.selection-mode:backdrop.flat:disabled:checked label,
headerbar button.selection-mode:backdrop:disabled:active label,
headerbar button.selection-mode:backdrop:disabled:checked label {
  color: #6c8aa9;
}

.titlebar:not(headerbar) button.selection-mode.flat:backdrop, .titlebar:not(headerbar) button.selection-mode.flat:disabled, .titlebar:not(headerbar) button.selection-mode.flat:backdrop:disabled,
headerbar button.selection-mode.flat:backdrop,
headerbar button.selection-mode.flat:disabled,
headerbar button.selection-mode.flat:backdrop:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.titlebar:not(headerbar) button.selection-mode:disabled,
headerbar button.selection-mode:disabled {
  border-color: #0f2b48;
  background-image: image(#21558b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.titlebar:not(headerbar) button.selection-mode:disabled label, .titlebar:not(headerbar) button.selection-mode:disabled,
headerbar button.selection-mode:disabled label,
headerbar button.selection-mode:disabled {
  color: #90aac5;
}

.titlebar:not(headerbar) button.selection-mode:disabled:active, .titlebar:not(headerbar) button.selection-mode:disabled:checked,
headerbar button.selection-mode:disabled:active,
headerbar button.selection-mode:disabled:checked {
  border-color: #0f2b48;
  background-image: image(#1b4672);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

.titlebar:not(headerbar) button.selection-mode:disabled:active label, .titlebar:not(headerbar) button.selection-mode:disabled:active, .titlebar:not(headerbar) button.selection-mode:disabled:checked label, .titlebar:not(headerbar) button.selection-mode:disabled:checked,
headerbar button.selection-mode:disabled:active label,
headerbar button.selection-mode:disabled:active,
headerbar button.selection-mode:disabled:checked label,
headerbar button.selection-mode:disabled:checked {
  color: #a4b5c7;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action,
headerbar button.selection-mode.suggested-action {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:hover,
headerbar button.selection-mode.suggested-action:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:active,
headerbar button.selection-mode.suggested-action:active {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  background-image: image(#25292b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:disabled,
headerbar button.selection-mode.suggested-action:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:disabled label, .titlebar:not(headerbar) button.selection-mode.suggested-action:disabled,
headerbar button.selection-mode.suggested-action:disabled label,
headerbar button.selection-mode.suggested-action:disabled {
  color: #f2f2f0;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop,
headerbar button.selection-mode.suggested-action:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop label, .titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop,
headerbar button.selection-mode.suggested-action:backdrop label,
headerbar button.selection-mode.suggested-action:backdrop {
  color: #f2f2f0;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop:disabled,
headerbar button.selection-mode.suggested-action:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

.titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop:disabled label, .titlebar:not(headerbar) button.selection-mode.suggested-action:backdrop:disabled,
headerbar button.selection-mode.suggested-action:backdrop:disabled label,
headerbar button.selection-mode.suggested-action:backdrop:disabled {
  color: #d1d1cc;
}

.titlebar:not(headerbar) button .selection-menu:backdrop, .titlebar:not(headerbar) button .selection-menu,
headerbar button .selection-menu:backdrop,
headerbar button .selection-menu {
  border-color: rgba(33, 93, 156, 0);
  background-color: rgba(33, 93, 156, 0);
  background-image: none;
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

.titlebar:not(headerbar) button .selection-menu:backdrop GtkArrow, .titlebar:not(headerbar) button .selection-menu GtkArrow,
headerbar button .selection-menu:backdrop GtkArrow,
headerbar button .selection-menu GtkArrow {
  -GtkArrow-arrow-scaling: 1;
}

.titlebar:not(headerbar) button .selection-menu:backdrop .arrow, .titlebar:not(headerbar) button .selection-menu .arrow,
headerbar button .selection-menu:backdrop .arrow,
headerbar button .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  color: rgba(255, 255, 255, 0.5);
  -gtk-icon-shadow: none;
}

.tiled .titlebar:backdrop:not(headerbar), .tiled .titlebar:not(headerbar),
.maximized .titlebar:backdrop:not(headerbar),
.maximized .titlebar:not(headerbar), .tiled
headerbar:backdrop, .tiled
headerbar,
.maximized
headerbar:backdrop,
.maximized
headerbar {
  border-radius: 0;
}

.default-decoration.titlebar:not(headerbar),
headerbar.default-decoration {
  min-height: 24px;
  padding: 2px;
}

.default-decoration.titlebar:not(headerbar) button.titlebutton,
headerbar.default-decoration button.titlebutton {
  min-height: 22px;
  min-width: 22px;
  margin: 0;
  padding: 0;
}

.solid-csd .titlebar:backdrop:dir(rtl):not(headerbar), .solid-csd .titlebar:backdrop:dir(ltr):not(headerbar), .solid-csd .titlebar:dir(rtl):not(headerbar), .solid-csd .titlebar:dir(ltr):not(headerbar), .solid-csd
headerbar:backdrop:dir(rtl), .solid-csd
headerbar:backdrop:dir(ltr), .solid-csd
headerbar:dir(rtl), .solid-csd
headerbar:dir(ltr) {
  margin-left: -1px;
  margin-right: -1px;
  margin-top: -1px;
  border-radius: 0;
  box-shadow: none;
}

headerbar entry,
headerbar spinbutton,
headerbar separator,
headerbar button {
  margin-top: 4px;
  margin-bottom: 4px;
}

headerbar switch {
  margin-top: 5px;
  margin-bottom: 5px;
}

.background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

window:not(.tiled):not(.maximized):not(.solid-csd) separator:first-child + headerbar:backdrop, window:not(.tiled):not(.maximized):not(.solid-csd) separator:first-child + headerbar,
window:not(.tiled):not(.maximized):not(.solid-csd) headerbar:first-child:backdrop,
window:not(.tiled):not(.maximized):not(.solid-csd) headerbar:first-child {
  border-top-left-radius: 4px;
}

window:not(.tiled):not(.maximized):not(.solid-csd) headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.solid-csd) headerbar:last-child {
  border-top-right-radius: 4px;
}

window:not(.tiled):not(.maximized):not(.solid-csd) stack headerbar:first-child:backdrop, window:not(.tiled):not(.maximized):not(.solid-csd) stack headerbar:first-child, window:not(.tiled):not(.maximized):not(.solid-csd) stack headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.solid-csd) stack headerbar:last-child {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

window.csd > .titlebar:not(headerbar) {
  padding: 0;
  background-color: transparent;
  background-image: none;
  border-style: none;
  border-color: transparent;
  box-shadow: none;
}

.titlebar:not(headerbar) > separator {
  background-color: #1b1f20;
}

/************
 * Pathbars *
 ************/
.path-bar button.text-button, .path-bar button.image-button, .path-bar button {
  padding-left: 4px;
  padding-right: 4px;
}

.path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
  padding-right: 8px;
}

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
  padding-left: 8px;
}

.path-bar button image {
  padding-left: 4px;
  padding-right: 4px;
}

.path-bar button.slider-button {
  padding-left: 0;
  padding-right: 0;
}

/**************
 * Tree Views *
 **************/
treeview.view {
  border-left-color: #898b8b;
  border-top-color: #33393b;
}

* {
  -GtkTreeView-horizontal-separator: 4;
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
}

treeview.view:selected:focus, treeview.view:selected {
  border-radius: 0;
}

treeview.view:selected:backdrop, treeview.view:selected {
  border-left-color: #90aece;
  border-top-color: rgba(238, 238, 236, 0.1);
}

treeview.view:disabled {
  color: #f2f2f0;
}

treeview.view:disabled:selected {
  color: #7a9ec4;
}

treeview.view:disabled:selected:backdrop {
  color: #638dba;
}

treeview.view:disabled:backdrop {
  color: #d1d1cc;
}

treeview.view.separator {
  min-height: 2px;
  color: #33393b;
}

treeview.view.separator:backdrop {
  color: rgba(51, 57, 59, 0.1);
}

treeview.view:backdrop {
  border-left-color: #939696;
  border-top: #33393b;
}

treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #0f2b48;
}

treeview.view:drop(active).after {
  border-top-style: none;
}

treeview.view:drop(active).before {
  border-bottom-style: none;
}

treeview.view.expander {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: #bdbebf;
}

treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

treeview.view.expander:hover {
  color: white;
}

treeview.view.expander:selected {
  color: #bccee1;
}

treeview.view.expander:selected:hover {
  color: #ffffff;
}

treeview.view.expander:selected:backdrop {
  color: #bccee1;
}

treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

treeview.view.expander:backdrop {
  color: #b5b6b5;
}

treeview.view.progressbar {
  border: 1px solid #0f2b48;
  border-radius: 4px;
  background-color: #215d9c;
  background-image: linear-gradient(to bottom, #215d9c, #184472);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), 0 1px rgba(0, 0, 0, 0.1);
}

treeview.view.progressbar:selected:focus, treeview.view.progressbar:selected {
  border-radius: 4px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #232729, #0c0d0d);
}

treeview.view.progressbar:selected:focus:backdrop, treeview.view.progressbar:selected:backdrop {
  border-color: #252a2c;
  background-color: #252a2c;
}

treeview.view.progressbar:backdrop {
  border-color: #252a2c;
  background-image: none;
  box-shadow: none;
}

treeview.view.trough {
  background-color: rgba(238, 238, 236, 0.1);
  border-radius: 4px;
}

treeview.view.trough:selected:focus, treeview.view.trough:selected {
  background-color: #184472;
  border-radius: 4px;
}

treeview.view header button {
  color: #898b8b;
  background-color: #232729;
  font-weight: bold;
  text-shadow: none;
  box-shadow: none;
}

treeview.view header button:hover {
  color: #bcbdbc;
  box-shadow: none;
  transition: none;
}

treeview.view header button:active {
  color: #eeeeec;
  transition: none;
}

treeview.view header button:last-child:backdrop, treeview.view header button:last-child {
  border-right-style: none;
}

treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd,
treeview.view header.button.dnd:active,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd {
  padding: 0 6px;
  color: #232729;
  background-image: none;
  background-color: #215d9c;
  border-style: none;
  border-radius: 0;
  box-shadow: inset 0 0 0 1px #232729;
  text-shadow: none;
  transition: none;
}

treeview.view acceleditor > label {
  background-color: #215d9c;
}

treeview.view header button, treeview.view header button:hover, treeview.view header button:active {
  padding: 0 6px;
  background-image: none;
  border-style: none solid solid none;
  border-color: #33393b;
  border-radius: 0;
  text-shadow: none;
}

treeview.view header button:disabled {
  border-color: #33393b;
  background-image: none;
}

treeview.view header button:backdrop {
  color: #939696;
  border-color: #33393b;
  border-style: none solid solid none;
  background-image: none;
  background-color: #252a2c;
}

treeview.view header button:backdrop:disabled {
  border-color: #33393b;
  background-image: none;
}

/*********
 * Menus *
 *********/
menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1);
  background-color: #232729;
}

menubar:backdrop,
.menubar:backdrop {
  background-color: #33393b;
}

menubar > menuitem,
.menubar > menuitem {
  color: #eeeeec;
  min-height: 16px;
  padding: 4px 8px;
}

menubar > menuitem:hover,
.menubar > menuitem:hover {
  box-shadow: inset 0 -3px #215d9c;
  color: #4a90d9;
}

menubar > menuitem:disabled,
.menubar > menuitem:disabled {
  color: #f2f2f0;
  box-shadow: none;
}

menubar > menuitem:backdrop label,
.menubar > menuitem:backdrop label {
  color: #f2f2f0;
}

menu,
.menu,
.context-menu, .gtk-combobox-popup-menu {
  margin: 4px;
  padding: 2px 0px;
  border: 1px solid #1b1f20;
}

.csd menu, .csd
.menu, .csd
.context-menu, .csd .gtk-combobox-popup-menu {
  border: none;
}

menu:backdrop,
.menu:backdrop,
.context-menu:backdrop, .gtk-combobox-popup-menu:backdrop {
  background-color: #282d2f;
}

menu menuitem,
.menu menuitem,
.context-menu menuitem, .gtk-combobox-popup-menu menuitem {
  color: #eeeeec;
  min-height: 16px;
  min-width: 40px;
  padding: 4px 6px;
  text-shadow: none;
}

menu menuitem:hover,
.menu menuitem:hover,
.context-menu menuitem:hover, .gtk-combobox-popup-menu menuitem:hover {
  color: #ffffff;
  background-color: #215d9c;
}

menu menuitem:disabled,
.menu menuitem:disabled,
.context-menu menuitem:disabled, .gtk-combobox-popup-menu menuitem:disabled {
  color: #f2f2f0;
}

menu menuitem:disabled:backdrop,
.menu menuitem:disabled:backdrop,
.context-menu menuitem:disabled:backdrop, .gtk-combobox-popup-menu menuitem:disabled:backdrop {
  color: #d1d1cc;
}

menu menuitem:backdrop, menu menuitem:backdrop:hover,
.menu menuitem:backdrop,
.menu menuitem:backdrop:hover,
.context-menu menuitem:backdrop,
.context-menu menuitem:backdrop:hover, .gtk-combobox-popup-menu menuitem:backdrop, .gtk-combobox-popup-menu menuitem:backdrop:hover {
  color: #f2f2f0;
  background-color: transparent;
}

menu menuitem arrow,
.menu menuitem arrow,
.context-menu menuitem arrow, .gtk-combobox-popup-menu menuitem arrow {
  min-height: 16px;
  min-width: 16px;
}

menu menuitem arrow:dir(ltr),
.menu menuitem arrow:dir(ltr),
.context-menu menuitem arrow:dir(ltr), .gtk-combobox-popup-menu menuitem arrow:dir(ltr) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  margin-left: 10px;
}

menu menuitem arrow:dir(rtl),
.menu menuitem arrow:dir(rtl),
.context-menu menuitem arrow:dir(rtl), .gtk-combobox-popup-menu menuitem arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
  margin-right: 10px;
}

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr),
.menu menuitem label:dir(rtl),
.menu menuitem label:dir(ltr),
.context-menu menuitem label:dir(rtl),
.context-menu menuitem label:dir(ltr), .gtk-combobox-popup-menu menuitem label:dir(rtl), .gtk-combobox-popup-menu menuitem label:dir(ltr) {
  color: inherit;
}

menu > arrow,
.menu > arrow,
.context-menu > arrow, .gtk-combobox-popup-menu > arrow {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  min-height: 16px;
  min-width: 16px;
  padding: 2px;
  background-color: #262b2d;
  border-radius: 0;
}

menu > arrow.top,
.menu > arrow.top,
.context-menu > arrow.top, .gtk-combobox-popup-menu > arrow.top {
  margin-top: -6px;
  border-bottom: 1px solid #373b3d;
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menu > arrow.bottom,
.menu > arrow.bottom,
.context-menu > arrow.bottom, .gtk-combobox-popup-menu > arrow.bottom {
  margin-bottom: -6px;
  border-top: 1px solid #373b3d;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menu > arrow:hover,
.menu > arrow:hover,
.context-menu > arrow:hover, .gtk-combobox-popup-menu > arrow:hover {
  background-color: #373b3d;
}

menu > arrow:backdrop,
.menu > arrow:backdrop,
.context-menu > arrow:backdrop, .gtk-combobox-popup-menu > arrow:backdrop {
  background-color: #282d2f;
}

menu > arrow:disabled,
.menu > arrow:disabled,
.context-menu > arrow:disabled, .gtk-combobox-popup-menu > arrow:disabled {
  color: transparent;
  background-color: transparent;
  border-color: transparent;
}

menuitem accelerator {
  color: alpha(currentColor,0.55);
}

menuitem check,
menuitem radio {
  min-height: 16px;
  min-width: 16px;
}

menuitem check:dir(ltr),
menuitem radio:dir(ltr) {
  margin-right: 7px;
}

menuitem check:dir(rtl),
menuitem radio:dir(rtl) {
  margin-left: 7px;
}

/***************
 * Popovers   *
 ***************/
popover.background {
  padding: 0px;
  border-radius: 3px;
  background-color: #33393b;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
}

.csd popover.background, popover.background {
  border: 1px solid #1b1f20;
}

popover.background:backdrop {
  background-color: #33393b;
  box-shadow: none;
}

popover.background > list,
popover.background > .view,
popover.background > iconview,
popover.background > toolbar {
  border-style: none;
  background-color: transparent;
}

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier {
  border: 1px solid rgba(255, 255, 255, 0.1);
}

popover.background separator {
  margin: 3px;
}

popover.background list separator {
  margin: 0px;
}

popover.menu {
  padding: 5px;
}

/*************
 * Notebooks *
 *************/
notebook > header {
  padding: 0px;
  border-color: #1b1f20;
  border-width: 1px;
  background-color: #272c2d;
}

notebook > header:backdrop {
  border-color: #202425;
  background-color: #2c3233;
}

notebook > header tabs, notebook > header tab {
  margin: 0px;
}

notebook > header tab {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header.top {
  border-bottom-style: solid;
}

notebook > header.top > tabs {
  margin-bottom: -1px;
}

notebook > header.top > tabs > tab {
  margin-bottom: -1px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -3px #1b1f20;
}

notebook > header.top > tabs > tab:backdrop {
  box-shadow: none;
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -3px #215d9c;
}

notebook > header.bottom {
  border-top-style: solid;
}

notebook > header.bottom > tabs {
  margin-top: -1px;
}

notebook > header.bottom > tabs > tab {
  margin-top: -1px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 3px #1b1f20;
}

notebook > header.bottom > tabs > tab:backdrop {
  box-shadow: none;
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 3px #215d9c;
}

notebook > header.left {
  border-right-style: solid;
}

notebook > header.left > tabs {
  margin-right: -1px;
}

notebook > header.left > tabs > tab {
  margin-right: -1px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -3px 0 #1b1f20;
}

notebook > header.left > tabs > tab:backdrop {
  box-shadow: none;
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -3px 0 #215d9c;
}

notebook > header.right {
  border-left-style: solid;
}

notebook > header.right > tabs {
  margin-left: -1px;
}

notebook > header.right > tabs > tab {
  margin-left: -1px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 3px 0 #1b1f20;
}

notebook > header.right > tabs > tab:backdrop {
  box-shadow: none;
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 3px 0 #215d9c;
}

notebook > header.top > tabs > arrow {
  border-top-style: none;
}

notebook > header.bottom > tabs > arrow {
  border-bottom-style: none;
}

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
  margin-left: -5px;
  margin-right: -5px;
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.left > tabs > arrow {
  border-left-style: none;
}

notebook > header.right > tabs > arrow {
  border-right-style: none;
}

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
  margin-top: -5px;
  margin-bottom: -5px;
  padding-top: 4px;
  padding-bottom: 4px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header > tabs > arrow {
  min-height: 16px;
  min-width: 16px;
  border-radius: 0;
}

notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) {
  background-clip: padding-box;
  background-image: none;
  background-color: rgba(255, 255, 255, 0.3);
  border-color: transparent;
  box-shadow: none;
}

notebook > header > tabs > arrow:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

notebook > header tab {
  min-height: 20px;
  min-width: 20px;
  padding: 1px 6px;
  margin: 0;
  outline-offset: -5px;
  color: #f2f2f0;
  font-weight: bold;
  border-width: 1px;
  border-color: transparent;
}

notebook > header tab:hover {
  color: #f0f0ee;
}

notebook > header tab:hover.reorderable-page {
  border-color: rgba(27, 31, 32, 0.3);
  background-color: rgba(51, 57, 59, 0.2);
}

notebook > header tab:backdrop {
  color: #a6a8a8;
}

notebook > header tab:backdrop.reorderable-page {
  border-color: transparent;
  background-color: transparent;
}

notebook > header tab:checked {
  color: #eeeeec;
}

notebook > header tab:checked.reorderable-page {
  border-color: rgba(27, 31, 32, 0.5);
  background-color: rgba(51, 57, 59, 0.5);
}

notebook > header tab:checked.reorderable-page:hover {
  background-color: rgba(51, 57, 59, 0.7);
}

notebook > header tab:backdrop:checked {
  color: #f2f2f0;
}

notebook > header tab:backdrop:checked.reorderable-page {
  border-color: #202425;
  background-color: #33393b;
}

notebook > header tab button.flat {
  padding: 0;
  margin-top: 2px;
  margin-bottom: 2px;
  min-width: 16px;
  min-height: 16px;
}

notebook > header tab button.flat:hover {
  color: currentColor;
}

notebook > header tab button.flat, notebook > header tab button.flat:backdrop {
  color: alpha(currentColor,0.3);
}

notebook > header tab button.flat:last-child {
  margin-left: 4px;
  margin-right: -4px;
}

notebook > header tab button.flat:first-child {
  margin-left: -4px;
  margin-right: 4px;
}

notebook > header.top tabs, notebook > header.bottom tabs {
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header.top tabs:not(:only-child), notebook > header.bottom tabs:not(:only-child) {
  margin-left: 3px;
  margin-right: 3px;
}

notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child {
  margin-left: -1px;
}

notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child {
  margin-right: -1px;
}

notebook > header.top tabs tab, notebook > header.bottom tabs tab {
  margin-left: 4px;
  margin-right: 4px;
}

notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page {
  border-style: none solid;
}

notebook > header.left tabs, notebook > header.right tabs {
  padding-top: 4px;
  padding-bottom: 4px;
}

notebook > header.left tabs:not(:only-child), notebook > header.right tabs:not(:only-child) {
  margin-top: 3px;
  margin-bottom: 3px;
}

notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child {
  margin-top: -1px;
}

notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child {
  margin-bottom: -1px;
}

notebook > header.left tabs tab, notebook > header.right tabs tab {
  margin-top: 4px;
  margin-bottom: 4px;
}

notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page {
  border-style: solid none;
}

notebook > header.top tab {
  padding-bottom: 4px;
}

notebook > header.bottom tab {
  padding-top: 4px;
}

notebook > stack:not(:only-child) {
  background-color: #232729;
}

notebook > stack:not(:only-child):backdrop {
  background-color: #252a2c;
}

/**************
 * Scrollbars *
 **************/
scrollbar {
  margin: -1px;
  min-width: 15px;
  background-color: #2b3032;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

scrollbarcontents {
  min-width: 10px;
}

* {
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
}

scrollbar.top {
  border-bottom: 1px solid #1b1f20;
}

scrollbar.bottom {
  border-top: 1px solid #1b1f20;
}

scrollbar.left {
  border-right: 1px solid #1b1f20;
}

scrollbar.right {
  border-left: 1px solid #1b1f20;
}

scrollbar:backdrop {
  background-color: #2c3133;
  border-color: #202425;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

scrollbar slider {
  min-width: 6px;
  min-height: 6px;
  margin: -1px;
  border: 4px solid transparent;
  border-radius: 8px;
  background-clip: padding-box;
  background-color: #a3a6a5;
}

scrollbar slider:hover {
  background-color: #c9cac9;
}

scrollbar slider:hover:active {
  background-color: #2a76c6;
}

scrollbar slider:backdrop {
  background-color: #7f8383;
}

scrollbar slider:disabled {
  background-color: transparent;
}

scrollbar.fine-tune slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  border-width: 5px 4px;
}

scrollbar.fine-tune.vertical slider {
  border-width: 4px 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  border-color: transparent;
  opacity: 0.4;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  margin: 0;
  min-width: 3px;
  min-height: 3px;
  background-color: #eeeeec;
  border: 1px solid black;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button {
  min-width: 5px;
  min-height: 5px;
  background-color: #eeeeec;
  background-clip: padding-box;
  border-radius: 100%;
  border: 1px solid black;
  -gtk-icon-source: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
  margin: 0 2px;
  min-width: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button {
  margin: 1px 2px;
  min-width: 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
  margin: 2px 0;
  min-height: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button {
  margin: 2px 1px;
  min-height: 5px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 0.8;
}

scrollbar.horizontal slider {
  min-width: 40px;
}

scrollbar.vertical slider {
  min-height: 40px;
}

scrollbar button {
  padding: 0;
  min-width: 12px;
  min-height: 12px;
  border-style: none;
  border-radius: 0;
  transition-property: min-height, min-width, color;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #a3a6a5;
}

scrollbar button:hover {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #c9cac9;
}

scrollbar button:active, scrollbar button:checked {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #2a76c6;
}

scrollbar button:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: rgba(163, 166, 165, 0.2);
}

scrollbar button:backdrop {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #7f8383;
}

scrollbar button:backdrop:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: rgba(127, 131, 131, 0.2);
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

treeview ~ scrollbar.vertical {
  border-top: 1px solid #1b1f20;
  margin-top: -1px;
}

/**********
 * Switch *
 **********/
switch {
  font-weight: bold;
  font-size: smaller;
  border-radius: 2px;
  outline-offset: -4px;
  color: #eeeeec;
  background-color: #272c2d;
  border: 1px solid #1b1f20;
  text-shadow: 0 1px rgba(0, 0, 0, 0.1);
}

switch:checked {
  color: #ffffff;
  border-color: #184472;
  background-color: #215d9c;
  text-shadow: 0 1px rgba(24, 68, 114, 0.5), 0 0 2px rgba(255, 255, 255, 0.6);
}

switch:disabled {
  color: #f2f2f0;
  border-color: #1b1f20;
  background-color: #2d3234;
  text-shadow: none;
}

switch:backdrop {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #f2f2f0;
  border-color: #202425;
  background-color: #2c3233;
  text-shadow: none;
}

switch:backdrop:checked {
  color: #33393b;
  border-color: #0f2b48;
  background-color: #215d9c;
}

switch:backdrop:disabled {
  color: #d1d1cc;
  border-color: #202425;
  background-color: #2d3234;
}

switch slider {
  margin: -1px;
  min-width: 35px;
  min-height: 22px;
  border: 1px solid;
  border-radius: 3px;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  background-image: linear-gradient(to bottom, #2c3133 20%, #25292b 90%);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2a2e30, inset 0 -1px #1e2122, 0 1px rgba(0, 0, 0, 0.1);
}

switch:hover slider {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2c3133, inset 0 -1px #25292b, 0 1px rgba(0, 0, 0, 0.1);
  background-image: linear-gradient(to bottom, #33393b 20%, #2a2e30 90%);
}

switch:checked slider {
  border: 1px solid #0f2b48;
}

switch:disabled slider {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

switch:disabled slider label, switch:disabled slider {
  color: #f2f2f0;
}

switch:backdrop slider {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

switch:backdrop slider label, switch:backdrop slider {
  color: #f2f2f0;
}

switch:backdrop:checked slider {
  border-color: #0f2b48;
}

switch:backdrop:disabled slider {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

switch:backdrop:disabled slider label, switch:backdrop:disabled slider {
  color: #d1d1cc;
}

/*************************
 * Check and Radio items *
 *************************/
.view.content-view.check:not(list), iconview.content-view.check:not(list),
.content-view .tile check:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:hover:not(list), iconview.content-view.check:hover:not(list),
.content-view .tile check:hover:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-hover-selectionmode.png"), url("assets/checkbox-hover-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:active:not(list), iconview.content-view.check:active:not(list),
.content-view .tile check:active:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-active-selectionmode.png"), url("assets/checkbox-active-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:backdrop:not(list), iconview.content-view.check:backdrop:not(list),
.content-view .tile check:backdrop:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-backdrop-selectionmode.png"), url("assets/checkbox-backdrop-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list),
.content-view .tile check:checked:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:checked:hover:not(list), iconview.content-view.check:checked:hover:not(list),
.content-view .tile check:checked:hover:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-hover-selectionmode.png"), url("assets/checkbox-checked-hover-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:checked:active:not(list), iconview.content-view.check:checked:active:not(list),
.content-view .tile check:checked:active:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-active-selectionmode.png"), url("assets/checkbox-checked-active-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

.view.content-view.check:backdrop:checked:not(list), iconview.content-view.check:backdrop:checked:not(list),
.content-view .tile check:backdrop:checked:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-selectionmode.png"), url("assets/checkbox-checked-backdrop-selectionmode@2.png"));
  background-color: transparent;
  min-width: 40px;
  min-height: 40px;
  background-image: none;
  transition: none;
  box-shadow: none;
  border-width: 0;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child {
  margin-left: 4px;
}

checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child {
  margin-right: 4px;
}

check,
radio {
  margin: 0 4px;
  min-height: 14px;
  min-width: 14px;
  border: 1px solid;
  -gtk-icon-source: none;
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  background-image: linear-gradient(to bottom, #2c3133 20%, #25292b 90%);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2a2e30, inset 0 -1px #1e2122, 0 1px rgba(0, 0, 0, 0.1);
}

check:only-child,
radio:only-child {
  margin: 0;
}

check:hover,
radio:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2c3133, inset 0 -1px #25292b, 0 1px rgba(0, 0, 0, 0.1);
  background-image: linear-gradient(to bottom, #33393b 20%, #2a2e30 90%);
}

check:active,
radio:active {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  background-image: image(#25292b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

check:disabled,
radio:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

check:disabled label, check:disabled,
radio:disabled label,
radio:disabled {
  color: #f2f2f0;
}

check:backdrop,
radio:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

check:backdrop label, check:backdrop,
radio:backdrop label,
radio:backdrop {
  color: #f2f2f0;
}

check:backdrop:disabled,
radio:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

check:backdrop:disabled label, check:backdrop:disabled,
radio:backdrop:disabled label,
radio:backdrop:disabled {
  color: #d1d1cc;
}

.osd check, .osd
radio {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd check:hover, .osd
radio:hover {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd check:active, .osd
radio:active {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
}

.osd check:backdrop, .osd
radio:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.osd check:disabled, .osd
radio:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

menu menuitem check, menu menuitem
radio {
  margin: 0;
}

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem
radio, menu menuitem
radio:hover, menu menuitem
radio:disabled {
  min-height: 14px;
  min-width: 14px;
  background-image: none;
  background-color: transparent;
  box-shadow: none;
  -gtk-icon-shadow: none;
  color: inherit;
  border-color: currentColor;
}


check {
  border-radius: 3px;
}


check:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/check-symbolic.symbolic.png"));
}


check:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/dash-symbolic.symbolic.png"));
}

treeview.view radio:selected:focus, treeview.view radio:selected,
radio {
  border-radius: 100%;
}

treeview.view radio:checked:selected,
radio:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/bullet-symbolic.symbolic.png"));
}

treeview.view radio:indeterminate:selected,
radio:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/dash-symbolic.symbolic.png"));
}

radio:not(:indeterminate):not(:checked):active:not(:backdrop) {
  -gtk-icon-transform: scale(0);
}

check:not(:indeterminate):not(:checked):active:not(:backdrop) {
  -gtk-icon-transform: translate(6px, -3px) rotate(-45deg) scaleY(0.2) rotate(45deg) scaleX(0);
}

radio:active,
check:active {
  -gtk-icon-transform: scale(0, 1);
}

radio:checked:not(:backdrop), radio:indeterminate:not(:backdrop),
check:checked:not(:backdrop),
check:indeterminate:not(:backdrop) {
  -gtk-icon-transform: unset;
  transition: 400ms;
}

menu menuitem radio:checked:not(:backdrop), menu menuitem radio:indeterminate:not(:backdrop),
menu menuitem check:checked:not(:backdrop),
menu menuitem check:indeterminate:not(:backdrop) {
  transition: none;
}

treeview.view check:selected:focus, treeview.view check:selected,
treeview.view radio:selected:focus,
treeview.view radio:selected {
  color: #eeeeec;
}

treeview.view check:selected:disabled,
treeview.view radio:selected:disabled {
  color: #f2f2f0;
}

treeview.view check:selected:disabled:backdrop,
treeview.view radio:selected:disabled:backdrop {
  color: #d1d1cc;
}

treeview.view check:backdrop:selected, treeview.view check:backdrop,
treeview.view radio:backdrop:selected,
treeview.view radio:backdrop {
  color: #f2f2f0;
}

/************
 * GtkScale *
 ************/
scale trough, scale fill, progressbar trough {
  min-height: 3px;
  border-radius: 3px;
  background-color: #272c2d;
}

scale trough:disabled, scale fill:disabled, progressbar trough:disabled {
  background-color: #2d3234;
}

scale trough:backdrop, scale fill:backdrop, progressbar trough:backdrop, progressbar:backdrop trough {
  background-color: #2c3233;
  border-color: #202425;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row:selected scale trough:disabled, scale row:selected trough:disabled, row:selected scale fill:disabled, scale row:selected fill:disabled, row:selected progressbar trough:disabled, progressbar row:selected trough:disabled, row:selected scale trough, scale row:selected trough, row:selected scale fill, scale row:selected fill, row:selected progressbar trough, progressbar row:selected trough {
  border-color: #0f2b48;
}

.osd scale trough, scale .osd trough, .osd scale fill, scale .osd fill, .osd progressbar trough, progressbar .osd trough {
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(0, 0, 0, 0.5);
}

.osd scale trough:disabled, scale .osd trough:disabled, .osd scale fill:disabled, scale .osd fill:disabled, .osd progressbar trough:disabled, progressbar .osd trough:disabled {
  background-color: rgba(49, 52, 52, 0.5);
}

scale highlight, progressbar progress {
  min-height: 3px;
  border-radius: 3px;
  background-color: #215d9c;
}

scale highlight:disabled, progressbar progress:disabled {
  background-color: transparent;
  border-color: transparent;
}

scale highlight:backdrop, progressbar progress:backdrop, progressbar:backdrop progress {
  border-color: #0f2b48;
}

scale highlight:backdrop:disabled, progressbar progress:backdrop:disabled, progressbar:backdrop progress:disabled {
  background-color: transparent;
  border-color: transparent;
}

row:selected scale highlight:disabled, scale row:selected highlight:disabled, row:selected progressbar progress:disabled, progressbar row:selected progress:disabled, row:selected scale highlight, scale row:selected highlight, row:selected progressbar progress, progressbar row:selected progress {
  border-color: #0f2b48;
}

.osd scale highlight, scale .osd highlight, .osd progressbar progress, progressbar .osd progress {
  border-color: rgba(0, 0, 0, 0.7);
}

.osd scale highlight:disabled, scale .osd highlight:disabled, .osd progressbar progress:disabled, progressbar .osd progress:disabled {
  border-color: transparent;
}

scale {
  min-height: 10px;
  min-width: 10px;
  padding: 12px;
}

scale fill,
scale highlight {
  margin: -1px;
}

scale slider {
  min-height: 18px;
  min-width: 18px;
  margin: -9px;
}

scale.fine-tune.horizontal {
  padding-top: 9px;
  padding-bottom: 9px;
  min-height: 16px;
}

scale.fine-tune.vertical {
  padding-left: 9px;
  padding-right: 9px;
  min-width: 16px;
}

scale.fine-tune slider {
  margin: -6px;
}

scale.fine-tune fill,
scale.fine-tune highlight,
scale.fine-tune trough {
  border-radius: 5px;
  -gtk-outline-radius: 7px;
}

scale trough {
  outline-offset: 2px;
  -gtk-outline-radius: 5px;
}

scale fill:backdrop, scale fill {
  background-color: #1b1f20;
}

scale fill:disabled:backdrop, scale fill:disabled {
  border-color: transparent;
  background-color: transparent;
}

.osd scale fill {
  background-color: rgba(91, 91, 90, 0.775);
}

.osd scale fill:disabled:backdrop, .osd scale fill:disabled {
  border-color: transparent;
  background-color: transparent;
}

scale slider {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  background-image: linear-gradient(to bottom, #2c3133 20%, #25292b 90%);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2a2e30, inset 0 -1px #1e2122, 0 1px rgba(0, 0, 0, 0.1);
  border: 1px solid #040404;
  border-radius: 100%;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border, box-shadow;
}

scale slider:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #0b0c0c;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #2c3133, inset 0 -1px #25292b, 0 1px rgba(0, 0, 0, 0.1);
  background-image: linear-gradient(to bottom, #33393b 20%, #2a2e30 90%);
}

scale slider:active {
  border-color: #0f2b48;
}

scale slider:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

scale slider:disabled label, scale slider:disabled {
  color: #f2f2f0;
}

scale slider:backdrop {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

scale slider:backdrop label, scale slider:backdrop {
  color: #f2f2f0;
}

scale slider:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

scale slider:backdrop:disabled label, scale slider:backdrop:disabled {
  color: #d1d1cc;
}

row:selected scale slider:disabled, row:selected scale slider {
  border-color: #0f2b48;
}

.osd scale slider {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: rgba(0, 0, 0, 0.7);
  background-color: #1c1f20;
}

.osd scale slider:hover {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(57, 63, 65, 0.7));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(238, 238, 236, 0.3);
  background-color: #1c1f20;
}

.osd scale slider:active {
  color: white;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  outline-color: rgba(238, 238, 236, 0.3);
  background-color: #1c1f20;
}

.osd scale slider:disabled {
  color: #858786;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(49, 52, 52, 0.5));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  background-color: #1c1f20;
}

.osd scale slider:backdrop {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(28, 31, 32, 0.7));
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  background-color: #1c1f20;
}

.osd scale slider:backdrop:disabled {
  background-color: #1c1f20;
}

scale value {
  color: alpha(currentColor,0.55);
}

scale marks {
  color: alpha(currentColor,0.55);
}

scale marks.top {
  margin-bottom: 6px;
  margin-top: -12px;
}

scale marks.bottom {
  margin-top: 6px;
  margin-bottom: -12px;
}

scale marks.top {
  margin-right: 6px;
  margin-left: -12px;
}

scale marks.bottom {
  margin-left: 6px;
  margin-right: -12px;
}

scale.fine-tune marks.top {
  margin-bottom: 6px;
  margin-top: -9px;
}

scale.fine-tune marks.bottom {
  margin-top: 6px;
  margin-bottom: -9px;
}

scale.fine-tune marks.top {
  margin-right: 6px;
  margin-left: -9px;
}

scale.fine-tune marks.bottom {
  margin-left: 6px;
  margin-right: -9px;
}

scale.horizontal indicator {
  min-height: 6px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 3px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 6px;
}

scale.vertical.fine-tune indicator {
  min-width: 3px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-dark.png"), url("assets/slider-horz-scale-has-marks-above-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover-dark.png"), url("assets/slider-horz-scale-has-marks-above-hover-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active-dark.png"), url("assets/slider-horz-scale-has-marks-above-active-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-above-insensitive-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider:backdrop {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop-dark.png"), url("assets/slider-horz-scale-has-marks-above-backdrop-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider:backdrop:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-dark.png"), url("assets/slider-horz-scale-has-marks-below-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-hover-dark.png"), url("assets/slider-horz-scale-has-marks-below-hover-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-active-dark.png"), url("assets/slider-horz-scale-has-marks-below-active-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-below-insensitive-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider:backdrop {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop-dark.png"), url("assets/slider-horz-scale-has-marks-below-backdrop-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider:backdrop:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive-dark@2.png"));
  min-height: 26px;
  min-width: 22px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-dark.png"), url("assets/slider-vert-scale-has-marks-above-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-hover-dark.png"), url("assets/slider-vert-scale-has-marks-above-hover-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-active-dark.png"), url("assets/slider-vert-scale-has-marks-above-active-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-above-insensitive-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider:backdrop {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop-dark.png"), url("assets/slider-vert-scale-has-marks-above-backdrop-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider:backdrop:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-dark.png"), url("assets/slider-vert-scale-has-marks-below-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-hover-dark.png"), url("assets/slider-vert-scale-has-marks-below-hover-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-active-dark.png"), url("assets/slider-vert-scale-has-marks-below-active-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-below-insensitive-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider:backdrop {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop-dark.png"), url("assets/slider-vert-scale-has-marks-below-backdrop-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider:backdrop:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive-dark@2.png"));
  min-height: 22px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.color {
  min-height: 0;
  min-width: 0;
}

scale.color trough {
  background-image: image(#1b1f20);
  background-repeat: no-repeat;
}

scale.color.horizontal {
  padding: 0 0 15px 0;
}

scale.color.horizontal trough {
  padding-bottom: 4px;
  background-position: 0 -3px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

scale.color.horizontal slider:dir(ltr):hover, scale.color.horizontal slider:dir(ltr):backdrop, scale.color.horizontal slider:dir(ltr):disabled, scale.color.horizontal slider:dir(ltr):backdrop:disabled, scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl):hover, scale.color.horizontal slider:dir(rtl):backdrop, scale.color.horizontal slider:dir(rtl):disabled, scale.color.horizontal slider:dir(rtl):backdrop:disabled, scale.color.horizontal slider:dir(rtl) {
  margin-bottom: -15px;
  margin-top: 6px;
}

scale.color.vertical:dir(ltr) {
  padding: 0 0 0 15px;
}

scale.color.vertical:dir(ltr) trough {
  padding-left: 4px;
  background-position: 3px 0;
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

scale.color.vertical:dir(ltr) slider:hover, scale.color.vertical:dir(ltr) slider:backdrop, scale.color.vertical:dir(ltr) slider:disabled, scale.color.vertical:dir(ltr) slider:backdrop:disabled, scale.color.vertical:dir(ltr) slider {
  margin-left: -15px;
  margin-right: 6px;
}

scale.color.vertical:dir(rtl) {
  padding: 0 15px 0 0;
}

scale.color.vertical:dir(rtl) trough {
  padding-right: 4px;
  background-position: -3px 0;
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

scale.color.vertical:dir(rtl) slider:hover, scale.color.vertical:dir(rtl) slider:backdrop, scale.color.vertical:dir(rtl) slider:disabled, scale.color.vertical:dir(rtl) slider:backdrop:disabled, scale.color.vertical:dir(rtl) slider {
  margin-right: -15px;
  margin-left: 6px;
}

scale.color.fine-tune.horizontal:dir(ltr), scale.color.fine-tune.horizontal:dir(rtl) {
  padding: 0 0 12px 0;
}

scale.color.fine-tune.horizontal:dir(ltr) trough, scale.color.fine-tune.horizontal:dir(rtl) trough {
  padding-bottom: 7px;
  background-position: 0 -6px;
}

scale.color.fine-tune.horizontal:dir(ltr) slider, scale.color.fine-tune.horizontal:dir(rtl) slider {
  margin-bottom: -15px;
  margin-top: 6px;
}

scale.color.fine-tune.vertical:dir(ltr) {
  padding: 0 0 0 12px;
}

scale.color.fine-tune.vertical:dir(ltr) trough {
  padding-left: 7px;
  background-position: 6px 0;
}

scale.color.fine-tune.vertical:dir(ltr) slider {
  margin-left: -15px;
  margin-right: 6px;
}

scale.color.fine-tune.vertical:dir(rtl) {
  padding: 0 12px 0 0;
}

scale.color.fine-tune.vertical:dir(rtl) trough {
  padding-right: 7px;
  background-position: -6px 0;
}

scale.color.fine-tune.vertical:dir(rtl) slider {
  margin-right: -15px;
  margin-left: 6px;
}

/*****************
 * Progress bars *
 *****************/
progressbar {
  font-size: smaller;
  color: rgba(238, 238, 236, 0.4);
}

progressbar.horizontal trough,
progressbar.horizontal progress {
  min-height: 2px;
}

progressbar.vertical trough,
progressbar.vertical progress {
  min-width: 2px;
}

progressbar.horizontal progress {
  margin: 0 -1px;
}

progressbar.vertical progress {
  margin: -1px 0;
}

progressbar:backdrop {
  box-shadow: none;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

progressbar progress {
  border-radius: 1.5px;
}

progressbar progress.left {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

progressbar progress.right {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

progressbar progress.top {
  border-top-right-radius: 2px;
  border-top-left-radius: 2px;
}

progressbar progress.bottom {
  border-bottom-right-radius: 2px;
  border-bottom-left-radius: 2px;
}

progressbar.osd {
  min-width: 3px;
  min-height: 3px;
  background-color: transparent;
}

progressbar.osd trough {
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  box-shadow: none;
}

progressbar.osd progress {
  border-style: none;
  border-radius: 0;
}

progressbar trough.empty progress {
  all: unset;
}

/*************
 * Level Bar *
 *************/
levelbar block {
  min-width: 32px;
  min-height: 1px;
}

levelbar.vertical block {
  min-width: 1px;
  min-height: 32px;
}

levelbar:backdrop {
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

levelbar trough {
  min-height: 3px;
  padding: 2px;
  border-radius: 3px;
  color: white;
  border-color: #1b1f20;
  background-color: #232729;
  box-shadow: inset 0 0 0 1px rgba(33, 93, 156, 0);
}

levelbar trough:backdrop {
  color: #fefefe;
  border-color: #202425;
  background-color: #252a2c;
  box-shadow: none;
}

levelbar.horizontal.discrete block {
  margin: 0 1px;
}

levelbar.vertical.discrete block {
  margin: 1px 0;
}

levelbar block {
  min-height: 3px;
  border-radius: 1px;
}

levelbar block.low {
  border-color: #f57900;
  background-color: #f57900;
}

levelbar block.low:backdrop {
  border-color: #f57900;
}

levelbar block.high, levelbar block:not(.empty) {
  border-color: #215d9c;
  background-color: #215d9c;
}

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop {
  border-color: #215d9c;
}

levelbar block.full {
  border-color: #5aa411;
  background-color: #5aa411;
}

levelbar block.full:backdrop {
  border-color: #5aa411;
}

levelbar block.empty {
  background-color: transparent;
  border-color: rgba(238, 238, 236, 0.1);
}

levelbar block.empty:backdrop {
  border-color: rgba(242, 242, 240, 0.15);
}

/****************
 * Print dialog *
*****************/
printdialog paper {
  color: #eeeeec;
  border: 1px solid #1b1f20;
  background: white;
  padding: 0;
}

printdialog paper:backdrop {
  color: #f2f2f0;
  border-color: #202425;
}

printdialog .dialog-action-box {
  margin: 12px;
}

/**********
 * Frames *
 **********/
.frame,
frame > border {
  margin: 0;
  padding: 0;
  border: 1px solid #1b1f20;
  border-radius: 0;
  box-shadow: none;
}

.frame.flat,
frame > border.flat {
  border-style: none;
}

.frame:backdrop,
frame > border:backdrop {
  border-color: #202425;
}

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid #1b1f20;
}

actionbar > revealer > box:backdrop {
  border-color: #202425;
}

scrolledwindow viewport.frame {
  border-style: none;
}

scrolledwindow overshoot.top {
  background-image: radial-gradient(farthest-side at top, #040404 85%, rgba(4, 4, 4, 0)), radial-gradient(farthest-side at top, rgba(238, 238, 236, 0.07), rgba(238, 238, 236, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.top:backdrop {
  background-image: radial-gradient(farthest-side at top, #202425 85%, rgba(32, 36, 37, 0));
  background-size: 100% 3%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, #040404 85%, rgba(4, 4, 4, 0)), radial-gradient(farthest-side at bottom, rgba(238, 238, 236, 0.07), rgba(238, 238, 236, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.bottom:backdrop {
  background-image: radial-gradient(farthest-side at bottom, #202425 85%, rgba(32, 36, 37, 0));
  background-size: 100% 3%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.left {
  background-image: radial-gradient(farthest-side at left, #040404 85%, rgba(4, 4, 4, 0)), radial-gradient(farthest-side at left, rgba(238, 238, 236, 0.07), rgba(238, 238, 236, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.left:backdrop {
  background-image: radial-gradient(farthest-side at left, #202425 85%, rgba(32, 36, 37, 0));
  background-size: 3% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.right {
  background-image: radial-gradient(farthest-side at right, #040404 85%, rgba(4, 4, 4, 0)), radial-gradient(farthest-side at right, rgba(238, 238, 236, 0.07), rgba(238, 238, 236, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.right:backdrop {
  background-image: radial-gradient(farthest-side at right, #202425 85%, rgba(32, 36, 37, 0));
  background-size: 3% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.top {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.bottom {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
  box-shadow: none;
}

scrolledwindow junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, #1b1f20 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: #2b3032;
}

scrolledwindow junction:dir(rtl) {
  border-image-slice: 0 1 0 0;
}

scrolledwindow junction:backdrop {
  border-image-source: linear-gradient(to bottom, #202425 1px, transparent 1px);
  background-color: #2c3133;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

separator {
  background: rgba(0, 0, 0, 0.1);
  min-width: 1px;
  min-height: 1px;
}

/*********
 * Lists *
 *********/
row {
  color: white;
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row:hover {
  transition: none;
}

row:backdrop {
  color: #fefefe;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.activatable.has-open-popup, row.activatable:hover {
  background-color: rgba(238, 238, 236, 0.05);
}

row.activatable:active {
  box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2);
}

row.activatable:backdrop:hover {
  background-color: transparent;
}

row.activatable:selected:active {
  box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5);
}

row.activatable:selected.has-open-popup, row.activatable:selected:hover {
  background-color: #356ca4;
}

/*********************
 * App Notifications *
 *********************/
.app-notification,
.app-notification.frame {
  padding: 10px;
  border-radius: 0 0 5px 5px;
  background-color: rgba(28, 31, 32, 0.7);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px);
  background-clip: padding-box;
}

.app-notification:backdrop,
.app-notification.frame:backdrop {
  background-image: none;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.app-notification border,
.app-notification.frame border {
  border: none;
}

/*************
 * Expanders *
 *************/
expander arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander arrow:hover {
  color: white;
}

expander arrow:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

/************
 * Calendar *
 ***********/
calendar {
  color: white;
  border: 1px solid #1b1f20;
}

calendar:selected {
  border-radius: 3px;
}

calendar.header {
  border-bottom-color: rgba(0, 0, 0, 0.1);
}

calendar.header:backdrop {
  border-bottom-color: rgba(0, 0, 0, 0.1);
}

calendar.button {
  color: rgba(238, 238, 236, 0.45);
}

calendar.button:hover {
  color: #eeeeec;
}

calendar.button:backdrop {
  color: rgba(242, 242, 240, 0.45);
}

calendar.button:disabled {
  color: rgba(242, 242, 240, 0.45);
}

calendar.highlight {
  color: #f2f2f0;
}

calendar.highlight:backdrop {
  color: #d1d1cc;
}

calendar:backdrop {
  color: #fefefe;
  border-color: #202425;
}

calendar:indeterminate {
  color: alpha(currentColor,0.1);
}

/***********
 * Dialogs *
 ***********/
messagedialog .titlebar {
  min-height: 16px;
  background-image: none;
  background-color: #33393b;
  border-style: none;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

messagedialog.csd.background {
  border-bottom-left-radius: 9px;
  border-bottom-right-radius: 9px;
}

messagedialog.csd .dialog-action-area button {
  padding: 3px 14px;
  border-radius: 0;
  border-left-style: solid;
  border-right-style: none;
  border-bottom-style: none;
}

messagedialog.csd .dialog-action-area button:first-child {
  border-left-style: none;
  border-bottom-left-radius: 4px;
  -gtk-outline-bottom-left-radius: 3px;
}

messagedialog.csd .dialog-action-area button:last-child {
  border-bottom-right-radius: 4px;
  -gtk-outline-bottom-right-radius: 3px;
}

filechooser .dialog-action-box {
  border-top: 1px solid #1b1f20;
}

filechooser .dialog-action-box:backdrop {
  border-top-color: #202425;
}

filechooser #pathbarbox {
  border-bottom: 1px solid #33393b;
}

filechooser #pathbarbox button {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

filechooser #pathbarbox button:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
}

filechooser #pathbarbox button:active {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  background-image: image(#25292b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

filechooser #pathbarbox button:disabled {
  border-color: #1b1f20;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

filechooser #pathbarbox button:disabled label, filechooser #pathbarbox button:disabled {
  color: #f2f2f0;
}

filechooser #pathbarbox button:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

filechooser #pathbarbox button:backdrop label, filechooser #pathbarbox button:backdrop {
  color: #f2f2f0;
}

filechooser #pathbarbox button:backdrop:disabled {
  border-color: #202425;
  background-image: image(#2d3234);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

filechooser #pathbarbox button:backdrop:disabled label, filechooser #pathbarbox button:backdrop:disabled {
  color: #d1d1cc;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

/***********
 * Sidebar *
 ***********/
.sidebar, treeview.sidebar list.tweak-categories, .primary-toolbar {
  background-color: #2b3032;
  color: white;
  border-style: none;
}

.sidebar > row, list.tweak-categories > row {
  color: white;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left, .sidebar.left:dir(rtl), list.tweak-categories:dir(ltr), list.tweak-categories.left, list.tweak-categories.left:dir(rtl) {
  border-right: 1px solid #1b1f20;
  border-left-style: none;
}

stacksidebar.sidebar:dir(rtl) list .sidebar:dir(rtl), stacksidebar.sidebar.right list .sidebar:dir(rtl), .sidebar.right, stacksidebar.sidebar:dir(rtl) list list.tweak-categories:dir(rtl), stacksidebar.sidebar.right list list.tweak-categories:dir(rtl), list.tweak-categories.right {
  border-left: 1px solid #1b1f20;
  border-right-style: none;
}

.sidebar:backdrop, list.tweak-categories:backdrop {
  color: #fefefe;
  background-color: #2c3133;
  border-color: #202425;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.sidebar list, list.tweak-categories list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar, paned list.tweak-categories.left, paned list.tweak-categories.right, paned list.tweak-categories.left:dir(rtl), paned list.tweak-categories:dir(rtl), paned list.tweak-categories:dir(ltr), paned list.tweak-categories {
  border-style: none;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list {
  border-color: #1b1f20;
}

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list {
  border-color: #1b1f20;
}

stacksidebar row {
  padding: 10px 4px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

/****************
 * File chooser *
 ****************/
placessidebar > viewport.frame {
  border-style: none;
}

placessidebar row {
  min-height: 26px;
  padding: 0px;
}

placessidebar row > revealer {
  padding: 0 8px;
}

placessidebar row:selected {
  color: #ffffff;
}

placessidebar row:disabled {
  color: #f2f2f0;
}

placessidebar row:backdrop {
  color: #f2f2f0;
}

placessidebar row:backdrop:selected {
  color: #fefefe;
}

placessidebar row:backdrop:disabled {
  color: #d1d1cc;
}

placessidebar row image.sidebar-icon {
  opacity: 0.7;
}

placessidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

button.sidebar-button {
  min-height: 26px;
  min-width: 26px;
  margin-top: 3px;
  margin-bottom: 3px;
  padding: 0;
  border-radius: 100%;
  -gtk-outline-radius: 100%;
}

button.sidebar-button:not(:hover):not(:active) > image, button.sidebar-button:backdrop > image {
  opacity: 0.7;
}

placessidebar row:selected:active {
  box-shadow: none;
}

placessidebar row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: image(#4e9a06);
  background-clip: content-box;
}

placessidebar row.sidebar-new-bookmark-row {
  color: #215d9c;
}

placessidebar row:drop(active):not(:disabled) {
  color: #4e9a06;
  box-shadow: inset 0 1px #4e9a06, inset 0 -1px #4e9a06;
}

placessidebar row:drop(active):not(:disabled):selected {
  color: #ffffff;
  background-color: #4e9a06;
}

placesview .server-list-button > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview row.activatable:hover {
  background-color: transparent;
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

.nautilus-window grid overlay *:first-child {
  border: 0;
}

frame {
  border: 0;
}

.titlebar.tweak-titlebar-right {
  min-height: 34px;
}

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(#1b1f20);
  background-size: 1px 1px;
}

paned > separator:selected {
  background-image: image(#215d9c);
}

paned > separator:backdrop {
  background-image: image(#202425);
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
  background-color: #33393b;
  background-image: image(#1b1f20), image(#1b1f20);
  background-size: 1px 1px, 1px 1px;
}

paned > separator.wide:backdrop {
  background-color: #33393b;
  background-image: image(#202425), image(#202425);
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

/**************
 * GtkInfoBar *
 **************/
infobar {
  border-style: none;
}

infobar.info, infobar.question, infobar.warning, infobar.error {
  text-shadow: 0 1px #184472;
}

infobar.info:backdrop, infobar.info, infobar.question:backdrop, infobar.question, infobar.warning:backdrop, infobar.warning, infobar.error:backdrop, infobar.error {
  background-color: #215d9c;
  border-color: #184472;
}

infobar.info:backdrop label, infobar.info:backdrop, infobar.info label, infobar.info, infobar.question:backdrop label, infobar.question:backdrop, infobar.question label, infobar.question, infobar.warning:backdrop label, infobar.warning:backdrop, infobar.warning label, infobar.warning, infobar.error:backdrop label, infobar.error:backdrop, infobar.error label, infobar.error {
  color: #ffffff;
}

infobar.info:backdrop, infobar.question:backdrop, infobar.warning:backdrop, infobar.error:backdrop {
  text-shadow: none;
}

infobar.info button, infobar.question button, infobar.warning button, infobar.error button {
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  background-image: linear-gradient(to bottom, #1f5894, #1d538b 60%, #1b4e83);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

infobar.info button:hover, infobar.question button:hover, infobar.warning button:hover, infobar.error button:hover {
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  border-bottom-color: #06121e;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.655529);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #2260a0, #1f5894 60%, #1d538b);
}

infobar.info button:active, infobar.info button:checked, infobar.question button:active, infobar.question button:checked, infobar.warning button:active, infobar.warning button:checked, infobar.error button:active, infobar.error button:checked {
  color: #ffffff;
  outline-color: rgba(255, 255, 255, 0.3);
  border-color: #0f2b48;
  background-image: image(#1b4e83);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
}

infobar.info button:disabled, infobar.question button:disabled, infobar.warning button:disabled, infobar.error button:disabled {
  border-color: #0f2b48;
  background-image: image(#21558b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

infobar.info button:disabled label, infobar.info button:disabled, infobar.question button:disabled label, infobar.question button:disabled, infobar.warning button:disabled label, infobar.warning button:disabled, infobar.error button:disabled label, infobar.error button:disabled {
  color: #90aac5;
}

infobar.info button:backdrop, infobar.question button:backdrop, infobar.warning button:backdrop, infobar.error button:backdrop {
  border-color: #0f2b48;
  background-image: image(#215d9c);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

infobar.info button:backdrop label, infobar.info button:backdrop, infobar.question button:backdrop label, infobar.question button:backdrop, infobar.warning button:backdrop label, infobar.warning button:backdrop, infobar.error button:backdrop label, infobar.error button:backdrop {
  color: #d3dfeb;
}

infobar.info button:backdrop:disabled, infobar.question button:backdrop:disabled, infobar.warning button:backdrop:disabled, infobar.error button:backdrop:disabled {
  border-color: #0f2b48;
  background-image: image(#21558b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  border-color: #0f2b48;
}

infobar.info button:backdrop:disabled label, infobar.info button:backdrop:disabled, infobar.question button:backdrop:disabled label, infobar.question button:backdrop:disabled, infobar.warning button:backdrop:disabled label, infobar.warning button:backdrop:disabled, infobar.error button:backdrop:disabled label, infobar.error button:backdrop:disabled {
  color: #6f91b4;
}

infobar.info selection, infobar.question selection, infobar.warning selection, infobar.error selection {
  background-color: #184472;
}

/************
 * Tooltips *
 ************/
tooltip {
  padding: 4px;
  /* not working */
  border-radius: 5px;
  box-shadow: none;
  text-shadow: 0 1px black;
}

tooltip.background {
  background-color: rgba(0, 0, 0, 0.8);
  background-clip: padding-box;
  border: 1px solid rgba(255, 255, 255, 0.1);
}

tooltip decoration {
  background-color: transparent;
}

tooltip * {
  padding: 4px;
  background-color: transparent;
  color: white;
}

/*****************
 * Color Chooser *
 *****************/
colorswatch:drop(active), colorswatch {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 5.5px;
  border-top-right-radius: 5.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
}

colorswatch.bottom {
  border-bottom-left-radius: 5.5px;
  border-bottom-right-radius: 5.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 5px;
  border-bottom-right-radius: 5px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 5.5px;
  border-bottom-left-radius: 5.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 5.5px;
  border-bottom-right-radius: 5.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
}

colorswatch.dark overlay {
  color: #ffffff;
}

colorswatch.dark overlay:hover {
  border-color: #1b1f20;
}

colorswatch.dark overlay:backdrop {
  color: #fefefe;
}

colorswatch.light overlay {
  color: white;
}

colorswatch.light overlay:hover {
  border-color: #1b1f20;
}

colorswatch.light overlay:backdrop {
  color: #fefefe;
}

colorswatch:drop(active) {
  box-shadow: none;
}

colorswatch:drop(active).light overlay {
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 2px #1b1f20, inset 0 0 0 1px #4e9a06;
}

colorswatch:drop(active).dark overlay {
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 2px #1b1f20, inset 0 0 0 1px #4e9a06;
}

colorswatch overlay {
  border: 1px solid #1b1f20;
}

colorswatch overlay:hover {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4), inset 0 -1px rgba(0, 0, 0, 0.2);
}

colorswatch overlay:backdrop, colorswatch overlay:backdrop:hover {
  border-color: #1b1f20;
  box-shadow: none;
}

colorswatch#add-color-button {
  border-radius: 5px 5px 0 0;
}

colorswatch#add-color-button:only-child {
  border-radius: 5px;
}

colorswatch#add-color-button overlay {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  background-image: linear-gradient(to bottom, #2e3436, #2a2e30 60%, #25292b);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.827451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

colorswatch#add-color-button overlay:hover {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1b1f20;
  border-bottom-color: #0b0c0c;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.779451);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
  background-image: linear-gradient(to bottom, #353c3e, #2e3436 60%, #2a2e30);
}

colorswatch#add-color-button overlay:backdrop {
  border-color: #202425;
  background-image: image(#33393b);
  text-shadow: none;
  -gtk-icon-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
}

colorswatch#add-color-button overlay:backdrop label, colorswatch#add-color-button overlay:backdrop {
  color: #f2f2f0;
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

row:selected colorswatch {
  box-shadow: 0 0 0 2px #ffffff;
}

colorswatch#editor-color-sample {
  border-radius: 4px;
}

colorswatch#editor-color-sample overlay {
  border-radius: 4.5px;
}

colorchooser .popover.osd {
  border-radius: 5px;
}

/********
 * Misc *
 ********/
.content-view {
  background-color: #222728;
}

.content-view:backdrop {
  background-color: #222728;
}

.osd .scale-popup button.flat {
  border-style: none;
  border-radius: 5px;
}

.scale-popup button:hover {
  background-color: rgba(238, 238, 236, 0.1);
  border-radius: 5px;
}

/**********************
 * Window Decorations *
 *********************/
decoration {
  border-radius: 4px 4px 0 0;
  border-width: 0px;
  box-shadow: 0 2px 4px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(27, 31, 32, 0.9);
  margin: 10px;
}

decoration:backdrop {
  box-shadow: 0 2px 4px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(27, 31, 32, 0.9);
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.maximized decoration,
.fullscreen decoration,
.tiled decoration {
  border-radius: 0;
}

.popup decoration {
  box-shadow: none;
}

.ssd decoration {
  box-shadow: 0 0 0 1px rgba(27, 31, 32, 0.9);
}

.csd.popup decoration {
  border-radius: 0;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(27, 31, 32, 0.8);
}

tooltip.csd decoration {
  border-radius: 5px;
  box-shadow: none;
}

messagedialog.csd decoration {
  border-radius: 4px;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(27, 31, 32, 0.8);
}

.solid-csd decoration {
  margin: 0;
  padding: 2px;
  background-color: #1b1f20;
  border: solid 1px #1b1f20;
  border-radius: 0;
  box-shadow: inset 0 0 0 3px #2c3133, inset 0 1px rgba(46, 52, 54, 0.07);
}

.solid-csd decoration:backdrop {
  box-shadow: inset 0 0 0 3px #33393b, inset 0 1px rgba(46, 52, 54, 0.07);
}

button.titlebutton {
  border-style: none;
  background-position: center;
  background-repeat: no-repeat;
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-dark.png"), url("assets/window-buttons/titlebutton-dark@2.png"));
}

button.titlebutton:backdrop {
  -gtk-icon-shadow: none;
}

button.titlebutton, button.titlebutton image, button.titlebutton:hover, button.titlebutton:hover image, button.titlebutton:active, button.titlebutton:active image {
  color: transparent;
}

button.titlebutton:backdrop {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-backdrop-dark.png"), url("assets/window-buttons/titlebutton-backdrop-dark@2.png"));
}

button.titlebutton.close:hover {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-close-hover-dark.png"), url("assets/window-buttons/titlebutton-close-hover-dark@2.png"));
  transition-duration: 150ms;
}

button.titlebutton.close:active {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-close-active-dark.png"), url("assets/window-buttons/titlebutton-close-active-dark@2.png"));
  transition-duration: 150ms;
}

button.titlebutton.minimize:hover {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-minimize-hover-dark.png"), url("assets/window-buttons/titlebutton-minimize-hover-dark@2.png"));
  transition-duration: 150ms;
}

button.titlebutton.minimize:active {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-minimize-active-dark.png"), url("assets/window-buttons/titlebutton-minimize-active-dark@2.png"));
  transition-duration: 150ms;
}

button.titlebutton.maximize:hover, button.titlebutton:not(.close):not(.maximize):not(.minimize):hover {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-maximize-hover-dark.png"), url("assets/window-buttons/titlebutton-maximize-hover-dark@2.png"));
  transition-duration: 150ms;
}

button.titlebutton.maximize:active, button.titlebutton:not(.close):not(.maximize):not(.minimize):active {
  background-image: -gtk-scaled(url("assets/window-buttons/titlebutton-maximize-active-dark.png"), url("assets/window-buttons/titlebutton-maximize-active-dark@2.png"));
  transition-duration: 150ms;
}

headerbar.selection-mode button.titlebutton,
.titlebar.selection-mode button.titlebutton {
  text-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.703529);
}

headerbar.selection-mode button.titlebutton:backdrop,
.titlebar.selection-mode button.titlebutton:backdrop {
  -gtk-icon-shadow: none;
}

.view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected, .view text:selected:focus, iconview text:selected:focus,
textview text:selected:focus, .view text:selected, iconview text:selected,
textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection,
entry selection, modelbutton.flat:selected,
.menuitem.button.flat:selected, treeview.view:selected:focus, treeview.view:selected, row:selected, calendar:selected {
  background-color: #215d9c;
}

row:selected label, label:selected, .selection-mode button.titlebutton, .view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected, .view text:selected:focus, iconview text:selected:focus,
textview text:selected:focus, .view text:selected, iconview text:selected,
textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection,
entry selection, modelbutton.flat:selected,
.menuitem.button.flat:selected, treeview.view:selected:focus, treeview.view:selected, row:selected, calendar:selected {
  color: #ffffff;
}

row:selected label:disabled, label:disabled:selected, .selection-mode button.titlebutton:disabled, iconview:disabled:selected:focus, .view:disabled:selected, iconview:disabled:selected, iconview text:disabled:selected:focus,
textview text:disabled:selected:focus, .view text:disabled:selected, iconview text:disabled:selected,
textview text:disabled:selected, iconview text selection:disabled:focus, .view text selection:disabled, iconview text selection:disabled,
textview text selection:disabled, flowbox flowboxchild:disabled:selected, label:disabled selection, spinbutton:not(.vertical) selection:disabled,
entry selection:disabled, modelbutton.flat:disabled:selected,
.menuitem.button.flat:disabled:selected, row:disabled:selected, calendar:disabled:selected {
  color: #90aece;
}

row:selected label:backdrop, label:backdrop:selected, .selection-mode button.titlebutton:backdrop, iconview:backdrop:selected:focus, .view:backdrop:selected, iconview:backdrop:selected, iconview text:backdrop:selected:focus,
textview text:backdrop:selected:focus, .view text:backdrop:selected, iconview text:backdrop:selected,
textview text:backdrop:selected, iconview text selection:backdrop:focus, .view text selection:backdrop, iconview text selection:backdrop,
textview text selection:backdrop, flowbox flowboxchild:backdrop:selected, label:backdrop selection, spinbutton:not(.vertical) selection:backdrop,
entry selection:backdrop, modelbutton.flat:backdrop:selected,
.menuitem.button.flat:backdrop:selected, row:backdrop:selected, calendar:backdrop:selected {
  color: #fefefe;
}

row:selected label:backdrop:disabled, label:backdrop:disabled:selected, .selection-mode button.titlebutton:backdrop:disabled, .view:backdrop:disabled:selected, iconview:backdrop:disabled:selected, .view text:backdrop:disabled:selected, iconview text:backdrop:disabled:selected,
textview text:backdrop:disabled:selected, .view text selection:backdrop:disabled, iconview text selection:backdrop:disabled,
textview text selection:backdrop:disabled, flowbox flowboxchild:backdrop:disabled:selected, label:disabled selection:backdrop, label:backdrop selection:disabled, spinbutton:not(.vertical) selection:backdrop:disabled,
entry selection:backdrop:disabled, modelbutton.flat:backdrop:disabled:selected,
.menuitem.button.flat:backdrop:disabled:selected, row:backdrop:disabled:selected, calendar:backdrop:disabled:selected {
  color: #638dba;
}

.monospace {
  font-family: monospace;
}

/**********************
 * Touch Copy & Paste *
 *********************/
cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
}

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-dark.png"), url("assets/text-select-start-dark@2.png"));
  padding-left: 10px;
}

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-dark.png"), url("assets/text-select-end-dark@2.png"));
  padding-right: 10px;
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-dark.png"), url("assets/slider-horz-scale-has-marks-above-dark@2.png"));
}

cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover-dark.png"), url("assets/text-select-start-hover-dark@2.png"));
  padding-left: 10px;
}

cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover-dark.png"), url("assets/text-select-end-hover-dark@2.png"));
  padding-right: 10px;
}

cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover-dark.png"), url("assets/slider-horz-scale-has-marks-above-hover-dark@2.png"));
}

cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active-dark.png"), url("assets/text-select-start-active-dark@2.png"));
  padding-left: 10px;
}

cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active-dark.png"), url("assets/text-select-end-active-dark@2.png"));
  padding-right: 10px;
}

cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active-dark.png"), url("assets/slider-horz-scale-has-marks-above-active-dark@2.png"));
}

.context-menu {
  font: initial;
}

.keycap {
  min-width: 20px;
  min-height: 25px;
  margin-top: 2px;
  padding-bottom: 3px;
  padding-left: 6px;
  padding-right: 6px;
  color: #eeeeec;
  background-color: #232729;
  border: 1px solid;
  border-color: #1b1f20;
  border-radius: 5px;
  box-shadow: inset 0 -3px #1e2223;
  font-size: smaller;
}

.keycap:backdrop {
  background-color: #252a2c;
  color: #f2f2f0;
  transition: all 250ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

:not(decoration):not(window):drop(active):focus,
:not(decoration):not(window):drop(active) {
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 1px #4e9a06;
  caret-color: #4e9a06;
}

stackswitcher button.text-button {
  min-width: 75px;
  min-height: 16px;
}

stackswitcher button.circular,
stackswitcher button.text-button.circular {
  min-width: 24px;
  min-height: 24px;
  padding: 0;
}

box > arrow, box > image {
  padding: 0 2px;
}

window.nautilus-desktop-window box.searchbar-container.vertical > searchbar, window.nautilus-desktop-window box.searchbar-container.vertical > searchbar:backdrop {
  background-color: transparent;
}

window.workbench docktabstrip {
  padding: 0px;
  border-color: #1b1f20;
  border-width: 1px;
  background-color: #272c2d;
  box-shadow: inset 0 -1px 0 0 #1b1f20;
}

window.workbench docktabstrip:backdrop {
  border-color: #202425;
  background-color: #2c3233;
}

window.workbench docktabstrip:backdrop {
  box-shadow: inset 0 -1px 0 0 #202425;
}

window.workbench docktab {
  min-height: 20px;
  min-width: 20px;
  padding: 1px 6px;
  margin: 0;
  outline-offset: -5px;
  color: #f2f2f0;
  font-weight: bold;
  border-width: 1px;
  border-color: transparent;
}

window.workbench docktab:hover {
  color: #f0f0ee;
}

window.workbench docktab:hover.reorderable-page {
  border-color: rgba(27, 31, 32, 0.3);
  background-color: rgba(51, 57, 59, 0.2);
}

window.workbench docktab:backdrop {
  color: #a6a8a8;
}

window.workbench docktab:backdrop.reorderable-page {
  border-color: transparent;
  background-color: transparent;
}

window.workbench docktab:checked {
  color: #eeeeec;
}

window.workbench docktab:checked.reorderable-page {
  border-color: rgba(27, 31, 32, 0.5);
  background-color: rgba(51, 57, 59, 0.5);
}

window.workbench docktab:checked.reorderable-page:hover {
  background-color: rgba(51, 57, 59, 0.7);
}

window.workbench docktab:backdrop:checked {
  color: #f2f2f0;
}

window.workbench docktab:backdrop:checked.reorderable-page {
  border-color: #202425;
  background-color: #33393b;
}

window.workbench docktab label {
  padding: 4px;
}

window.workbench docktab:hover {
  box-shadow: inset 0 -3px #1b1f20;
}

window.workbench docktab:backdrop {
  box-shadow: none;
}

window.workbench docktab:checked {
  box-shadow: inset 0 -3px #215d9c;
}

window.workbench layouttab {
  box-shadow: inset 0 -3px #215d9c;
}

window.workbench layouttab box button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  padding: 2px 8px;
}

window.workbench layouttab box button:backdrop {
  border: none;
  background-image: none;
  box-shadow: none;
}

window.workbench greeter frame {
  border: 1px solid #1b1f20;
}

.tweak-titlebar-left {
  border-color: #1b1f20;
}

.tweak-titlebar-left:backdrop {
  border-color: #202425;
}

viewport.frame > list.tweak-categories {
  background-image: image(#2b3032);
  color: #eeeeec;
}

viewport.frame > list.tweak-categories label:backdrop {
  color: #f2f2f0;
}

.primary-toolbar button.raised {
  margin: 0px;
}

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #eeeeec;
/*
text color for entries, views and content in general */
@define-color theme_text_color white;
/*
widget base background color */
@define-color theme_bg_color #33393b;
/*
text widgets and the like base background color */
@define-color theme_base_color #232729;
/*
base background color of selections */
@define-color theme_selected_bg_color #215d9c;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #ffffff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #2d3234;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #f2f2f0;
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #232729;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #f2f2f0;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color white;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #33393b;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #252a2c;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #215d9c;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #ffffff;
/*
insensitive color on backdrop windows*/
@define-color unfocused_insensitive_color #d1d1cc;
/*
widgets main borders color */
@define-color borders #1b1f20;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #202425;
/*
these are pretty self explicative */
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #5aa411;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#eeeeec, 1.8);
@define-color wm_unfocused_title #f2f2f0;
@define-color wm_highlight transparent;
@define-color wm_borders_edge rgba(46, 52, 54, 0.07);
@define-color wm_bg_a shade(#33393b, 1.2);
@define-color wm_bg_b #33393b;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#33393b, 1.3);
@define-color wm_button_hover_color_b #33393b;
@define-color wm_button_active_color_a shade(#33393b, 0.85);
@define-color wm_button_active_color_b shade(#33393b, 0.89);
@define-color wm_button_active_color_c shade(#33393b, 0.9);
@define-color content_view_bg #232729;
